#!/usr/bin/env python
"""Definitions and properties of amino-acids for p2smi"""

# Natural Amino-acids:

all_aminos = {
    "Phenylglycine": {
        "Code": "PG",
        "Formula": "C8H9NO2",
        "Letter": "Ḁ",
        "MolWeight": 151.063328528,
        "SMILES": "N[C@@H](c1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-methoxy-Phenylalanine": {
        "Code": "0A1",
        "Formula": "C10H13NO3",
        "Letter": "Ạ",
        "MolWeight": 195.089543276,
        "SMILES": "N[C@@H](Cc1ccc(OC)cc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "7-hydroxy-l-tryptophan": {
        "Code": "0AF",
        "Formula": "C11H12N2O3",
        "Letter": "Ả",
        "MolWeight": 220.084792244,
        "SMILES": "N[C@@H](Cc1c[nH]c2c1cccc2O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-carbamimidoyl-l-phenylalanine": {
        "Code": "0BN",
        "Formula": "C10H13N3O2",
        "Letter": "Ấ",
        "MolWeight": 207.100776656,
        "SMILES": "N[C@@H](Cc1ccc(cc1)C(=N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](Cc1ccc(cc1)C(=N*)N)C(=O)O",
    },
    "4-chloro-Phenylalanine": {
        "Code": "4CP",
        "Formula": "C9H10ClNO2",
        "Letter": "Ầ",
        "MolWeight": 199.04000624,
        "SMILES": "N[C@@H](Cc1ccc(cc1)Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-Allyl-glycine": {
        "Code": "2AG",
        "Formula": "C7H11NO5",
        "Letter": "Ẫ",
        "MolWeight": 189.063722452,
        "SMILES": "N[C@@H](CCCC(C(=O)O)=O)C(=O)O",
        "cterm": "N[C@@H](CCCC(C*(=O))=O)C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-methyl-aspartic-acid": {
        "Code": "2AS",
        "Formula": "C5H9NO4",
        "Letter": "Ậ",
        "MolWeight": 147.053157768,
        "SMILES": "N[C@H]([C@H](C)(C(=O)O))C(=O)O",
        "cterm": "N[C@H]([C@H](C)(C*(=O)))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "s-(difluoromethyl)-homocysteine": {
        "Code": "2FM",
        "Formula": "C5H9F2NO2S",
        "Letter": "Ắ",
        "MolWeight": 185.032205968,
        "SMILES": "N[C@@H](CCSC(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-fluoro-l-histidine": {
        "Code": "2HF",
        "Formula": "C6H12FN3O2",
        "Letter": "Ằ",
        "MolWeight": 177.091354844,
        "SMILES": "N[C@@H](C[C@@H]1CN[C@@H](N1)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-fluoro-l-histidine(1)": {
        "Code": "2HF1",
        "Formula": "C6H8FN3O2",
        "Letter": "Ẳ",
        "MolWeight": 173.060054716,
        "SMILES": "N[C@@H](Cc1cnc(F)N1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-fluoro-l-histidine(2)": {
        "Code": "2HF2",
        "Formula": "C6H8FN3O2",
        "Letter": "Ẵ",
        "MolWeight": 173.060054716,
        "SMILES": "N[C@@H](Cc1c[nH]c(n1)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "l-2-amino-6-methylene-pimelic-acid": {
        "Code": "2NP",
        "Formula": "C8H13NO4",
        "Letter": "Ặ",
        "MolWeight": 187.084457896,
        "SMILES": "N[C@@H](CCCC(=C)C(=O)O)C(=O)O",
        "cterm": "N[C@@H](CCCC(=C)C*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(4H-thieno[3,2-b]pyrrol-6-yl)-L-alanine": {
        "Code": "32T",
        "Formula": "C9H10N2O2S",
        "Letter": "Ḃ",
        "MolWeight": 210.04629856,
        "SMILES": "N[C@H](Cc1c[nH]c2c1scc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-cyano-phenylalanine": {
        "Code": "3CF",
        "Formula": "C10H10N2O2",
        "Letter": "Ḅ",
        "MolWeight": 190.07422756,
        "SMILES": "N[C@@H](Cc1cccc(C#N)c1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "(2s)-amino(3,5-dihydroxyphenyl)-ethanoic-acid": {
        "Code": "3FG",
        "Formula": "C8H9NO4",
        "Letter": "Ḇ",
        "MolWeight": 183.053157768,
        "SMILES": "N[C@@H](c1cc(O)cc(c1)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@@H](c1cc(O*)cc(c1)O)C(=O)O",
        "nterm": False,
    },
    "4-hydroxy-glutamic-acid": {
        "Code": "3GL",
        "Formula": "C5H9NO5",
        "Letter": "Ḉ",
        "MolWeight": 163.048072388,
        "SMILES": "N[C@@H](C[C@@H](C(=O)O)O)C(=O)O",
        "cterm": "N[C@@H](C[C@@H](C*(=O))O)C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-Chloro-tyrosine": {
        "Code": "3MY",
        "Formula": "C9H10ClNO3",
        "Letter": "Ḋ",
        "MolWeight": 215.03492086,
        "SMILES": "N[C@H](Cc1ccc(c(c1)Cl)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-Bromo-phenylalanine": {
        "Code": "4BF",
        "Formula": "C9H10BrNO2",
        "Letter": "Ḍ",
        "MolWeight": 242.98949066,
        "SMILES": "N[C@@H](Cc1ccc(cc1)Br)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-cyano-phenylalanine": {
        "Code": "4CF",
        "Formula": "C10H10N2O2",
        "Letter": "Ḏ",
        "MolWeight": 190.07422756,
        "SMILES": "N[C@@H](Cc1ccc(cc1)C#N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "nitrilo-l-methionine": {
        "Code": "4CY",
        "Formula": "C5H8N2O2S",
        "Letter": "Ḑ",
        "MolWeight": 160.030648496,
        "SMILES": "N[C@@H](CCSC#N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-fluoro-tryptophan": {
        "Code": "4FW",
        "Formula": "C11H11FN2O2",
        "Letter": "Ḓ",
        "MolWeight": 222.080455812,
        "SMILES": "N[C@@H](Cc1c[nH]c2c1c(F)ccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-hydroxymethyl-phenylalanine": {
        "Code": "4HMP",
        "Formula": "C10H13NO3",
        "Letter": "Ḕ",
        "MolWeight": 195.089543276,
        "SMILES": "N[C@@H](Cc1ccc(CO)cc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-hydroxy-tryptophan": {
        "Code": "4HT",
        "Formula": "C11H12N2O3",
        "Letter": "Ḗ",
        "MolWeight": 220.084792244,
        "SMILES": "N[C@@H](Cc1c[nH]c2c1c(O)ccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@@H](Cc1c[nH]c2c1c(O*)ccc2)C(=O)O",
        "nterm": False,
    },
    "4-amino-l-tryptophan": {
        "Code": "4IN",
        "Formula": "C11H13N3O2",
        "Letter": "Ḙ",
        "MolWeight": 219.100776656,
        "SMILES": "N[C@@H](Cc1c[nH]c2c1c(N)ccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-methyl-phenylalanine": {
        "Code": "4PH",
        "Formula": "C10H13NO2",
        "Letter": "Ḛ",
        "MolWeight": 179.094628656,
        "SMILES": "N[C@@H](Cc1ccc(cc1)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "6-carboxylysine": {
        "Code": "6CL",
        "Formula": "C7H14N2O4",
        "Letter": "Ḝ",
        "MolWeight": 190.095356928,
        "SMILES": "N[C@@H](CCC[C@H](C(=O)O)N)C(=O)O",
        "cterm": "N[C@@H](CCC[C@H](C*(=O))N)C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CCC[C@H](C(=O)O)N*)C(=O)O",
    },
    "6-chloro-l-tryptophan": {
        "Code": "6CW",
        "Formula": "C11H11ClN2O2",
        "Letter": "Ẹ",
        "MolWeight": 238.050905272,
        "SMILES": "N[C@@H](Cc1c[nH]c2c1ccc(c2)Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-amino-5-hydroxypentanoic-acid": {
        "Code": "AA4",
        "Formula": "C5H11NO3",
        "Letter": "Ẻ",
        "MolWeight": 133.073893212,
        "SMILES": "N[C@@H](CCCO)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@@H](CCCO*)C(=O)O",
        "nterm": False,
    },
    "2-Aminobutyric-acid": {
        "Code": "ABA",
        "Formula": "C4H9NO2",
        "Letter": "Ẽ",
        "MolWeight": 103.063328528,
        "SMILES": "N[C@@H](CC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "cis-amiclenomycin": {
        "Code": "ACZ",
        "Formula": "C10H16N2O2",
        "Letter": "Ế",
        "MolWeight": 196.121177752,
        "SMILES": "N[C@@H](CC[C@@H]1C=C[C@@H](C=C1)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CC[C@@H]1C=C[C@@H](C=C1)N*)C(=O)O",
    },
    "Adamanthane": {
        "Code": "ADAM",
        "Formula": "C13H21NO2",
        "Letter": "Ề",
        "MolWeight": 223.157228912,
        "SMILES": "N[C@@H](C[C@]12C[C@H]3C[C@@H](C2)C[C@@H](C1)C3)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "5-methyl-arginine": {
        "Code": "AGM",
        "Formula": "C7H16N4O2",
        "Letter": "Ể",
        "MolWeight": 188.127325752,
        "SMILES": "N[C@@H](CC[C@H](C)NC(=N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CC[C@H](C)NC(=N*)N)C(=O)O",
    },
    "beta-hydroxyasparagine": {
        "Code": "AHB",
        "Formula": "C4H8N2O4",
        "Letter": "Ễ",
        "MolWeight": 148.048406736,
        "SMILES": "N[C@@H]([C@@H](C(=O)N)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-Aminoheptanoic-acid": {
        "Code": "AHP",
        "Formula": "C7H15NO2",
        "Letter": "Ệ",
        "MolWeight": 145.11027872,
        "SMILES": "N[C@@H](CCCCC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-cyclohexyl-alanine": {
        "Code": "ALC",
        "Formula": "C9H17NO2",
        "Letter": "Ḟ",
        "MolWeight": 171.125928784,
        "SMILES": "N[C@@H](CC1CCCCC1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "1-Naphthyl-alanine": {
        "Code": "ALN",
        "Formula": "C13H13NO2",
        "Letter": "Ḡ",
        "MolWeight": 215.094628656,
        "SMILES": "N[C@@H](Cc1cccc2c1cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Allo-threonine": {
        "Code": "ALO",
        "Formula": "C4H9NO3",
        "Letter": "Ḣ",
        "MolWeight": 119.058243148,
        "SMILES": "N[C@@H]([C@H](C)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(9-anthryl)-alanine": {
        "Code": "ANTH",
        "Formula": "C17H15NO2",
        "Letter": "Ḥ",
        "MolWeight": 265.11027872,
        "SMILES": "N[C@@H](Cc1c2ccccc2cc2c1cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-Methyl-phenylalanine": {
        "Code": "APD",
        "Formula": "C10H13NO2",
        "Letter": "Ḧ",
        "MolWeight": 179.094628656,
        "SMILES": "N[C@@H](Cc1cccc(c1)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "m-amidinophenyl-3-alanine": {
        "Code": "APM",
        "Formula": "C10H13N3O2",
        "Letter": "Ḩ",
        "MolWeight": 207.100776656,
        "SMILES": "N[C@@H](Cc1cccc(c1)C(=N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](Cc1cccc(c1)C(=N*)N)C(=O)O",
    },
    "c-gamma-hydroxy-arginine": {
        "Code": "ARO",
        "Formula": "C6H14N4O3",
        "Letter": "Ḫ",
        "MolWeight": 190.106590308,
        "SMILES": "N[C@@H](C[C@@H](O)CN=C(N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](C[C@@H](O)CN=C(N)N*)C(=O)O",
    },
    "(2r)-2-amino-4-oxobutanoic-acid": {
        "Code": "AS2",
        "Formula": "C4H7NO3",
        "Letter": "Ỉ",
        "MolWeight": 117.042593084,
        "SMILES": "N[C@@H](CC=O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "azido-alanine": {
        "Code": "AZDA",
        "Formula": "C3H7N4O2+",
        "Letter": "Ị",
        "MolWeight": 131.05635188409,
        "SMILES": "N[C@@H](CN=[N+]=N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Phenylserine": {
        "Code": "BB8",
        "Formula": "C9H11NO3",
        "Letter": "Ḭ",
        "MolWeight": 181.073893212,
        "SMILES": "N[C@@H]([C@@H](O)c1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "benzylcysteine": {
        "Code": "BCS",
        "Formula": "C10H13NO2S",
        "Letter": "Ḯ",
        "MolWeight": 211.066699656,
        "SMILES": "N[C@@H](CSCc1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "beta-hydroxyaspartic-acid": {
        "Code": "BHD",
        "Formula": "C4H7NO5",
        "Letter": "Ḱ",
        "MolWeight": 149.032422324,
        "SMILES": "N[C@@H]([C@H](O)C(=O)O)C(=O)O",
        "cterm": "N[C@@H]([C@H](O)C*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4,4-biphenylalanine": {
        "Code": "BIF",
        "Formula": "C15H15NO2",
        "Letter": "Ḳ",
        "MolWeight": 241.11027872,
        "SMILES": "N[C@@H](Cc1ccc(cc1)c1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "5-bromo-l-isoleucine": {
        "Code": "BIU",
        "Formula": "C6H12BrNO2",
        "Letter": "Ḵ",
        "MolWeight": 209.005140724,
        "SMILES": "N[C@@H]([C@@H](C)CCBr)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(3-benzothienyl)-alanine": {
        "Code": "BTH3",
        "Formula": "C11H11NO2S",
        "Letter": "Ḷ",
        "MolWeight": 221.051049592,
        "SMILES": "N[C@@H](Cc1csc2c1cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "6-bromo-tryptophan": {
        "Code": "BTR",
        "Formula": "C11H11BrN2O2",
        "Letter": "Ḹ",
        "MolWeight": 282.000389692,
        "SMILES": "N[C@@H](Cc1c[nH]c2c1ccc(c2)Br)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Tertleucine": {
        "Code": "BUG",
        "Formula": "C6H13NO2",
        "Letter": "Ḻ",
        "MolWeight": 131.094628656,
        "SMILES": "N[C@@H](C(C)(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-chloro-l-alanine": {
        "Code": "C2N",
        "Formula": "C3H6ClNO2",
        "Letter": "Ḽ",
        "MolWeight": 123.008706112,
        "SMILES": "N[C@@H](CCl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "canaline": {
        "Code": "CAN",
        "Formula": "C4H10N2O3",
        "Letter": "Ḿ",
        "MolWeight": 134.06914218,
        "SMILES": "N[C@@H](CCON)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CCON*)C(=O)O",
    },
    "carboxymethylated-cysteine": {
        "Code": "CCS",
        "Formula": "C5H9NO4S",
        "Letter": "Ṁ",
        "MolWeight": 179.025228768,
        "SMILES": "N[C@@H](CSCC(=O)O)C(=O)O",
        "cterm": "N[C@@H](CSCC*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Cyclohexylglycine": {
        "Code": "CHG",
        "Formula": "C8H15NO2",
        "Letter": "Ṃ",
        "MolWeight": 157.11027872,
        "SMILES": "N[C@@H](C1CCCCC1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-chloro-4-hydroxy-phenylglycine": {
        "Code": "CHP",
        "Formula": "C8H8ClNO3",
        "Letter": "Ṅ",
        "MolWeight": 201.019270796,
        "SMILES": "N[C@@H](c1ccc(c(c1)Cl)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Citrulline": {
        "Code": "CIR",
        "Formula": "C6H13N3O3",
        "Letter": "Ṇ",
        "MolWeight": 175.095691276,
        "SMILES": "N[C@@H](CCC[NH]C(=O)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CCC[NH]C(=O)N*)C(=O)O",
    },
    "2-cyano-phenylalanine": {
        "Code": "CNP2",
        "Formula": "C10H10N2O2",
        "Letter": "Ṉ",
        "MolWeight": 190.07422756,
        "SMILES": "N[C@@H](Cc1ccccc1C#N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2,4-dichloro-phenylalanine": {
        "Code": "CP24",
        "Formula": "C9H9Cl2NO2",
        "Letter": "Ṋ",
        "MolWeight": 233.001033888,
        "SMILES": "N[C@@H](Cc1ccc(cc1Cl)Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3,4-dichloro-phenylalanine": {
        "Code": "CP34",
        "Formula": "C9H9Cl2NO2",
        "Letter": "Ọ",
        "MolWeight": 233.001033888,
        "SMILES": "N[C@@H](Cc1ccc(c(c1)Cl)Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-Cyclopentyl-alanine": {
        "Code": "CPA3",
        "Formula": "C8H15NO2",
        "Letter": "Ỏ",
        "MolWeight": 157.11027872,
        "SMILES": "N[C@@H](CC1CCCC1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-Chloro-phenylglycine": {
        "Code": "CPG2",
        "Formula": "C8H8ClNO2",
        "Letter": "Ố",
        "MolWeight": 185.024356176,
        "SMILES": "N[C@@H](c1ccccc1Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-Chloro-phenylglycine": {
        "Code": "CPG3",
        "Formula": "C8H8ClNO2",
        "Letter": "Ồ",
        "MolWeight": 185.024356176,
        "SMILES": "N[C@@H](c1cccc(c1)Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-Chloro-phenylglycine": {
        "Code": "CPG4",
        "Formula": "C8H8ClNO2",
        "Letter": "Ổ",
        "MolWeight": 185.024356176,
        "SMILES": "N[C@@H](c1ccc(cc1)Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-chloro-Phenylalanine": {
        "Code": "CPH2",
        "Formula": "C9H10ClNO2",
        "Letter": "Ỗ",
        "MolWeight": 199.04000624,
        "SMILES": "N[C@@H](Cc1ccccc1Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "s-acetonylcysteine": {
        "Code": "CSA",
        "Formula": "C6H11NO3S",
        "Letter": "Ộ",
        "MolWeight": 177.045964212,
        "SMILES": "N[C@@H](CSCC(=O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Selenocysteine": {
        "Code": "CSE",
        "Formula": "C3H7NO2Se",
        "Letter": "Ớ",
        "MolWeight": 168.964199764,
        "SMILES": "N[C@@H](C[SeH])C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "7-chloro-tryptophan": {
        "Code": "CTE",
        "Formula": "C11H11ClN2O2",
        "Letter": "Ờ",
        "MolWeight": 238.050905272,
        "SMILES": "N[C@@H](Cc1cNc2c1cccc2Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-chloro-threonine": {
        "Code": "CTH",
        "Formula": "C4H8ClNO3",
        "Letter": "Ở",
        "MolWeight": 153.019270796,
        "SMILES": "N[C@@H]([C@H](O)CCl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-Hydroxy-phenylglycine": {
        "Code": "D4P",
        "Formula": "C8H9NO3",
        "Letter": "Ỡ",
        "MolWeight": 167.058243148,
        "SMILES": "N[C@@H](c1ccc(cc1)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Diaminobutyric-acid": {
        "Code": "DAB",
        "Formula": "C4H10N2O2",
        "Letter": "Ợ",
        "MolWeight": 118.07422756,
        "SMILES": "N[C@@H](CCN)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CCN*)C(=O)O",
    },
    "3,4-Dihydroxy-phenylalanine": {
        "Code": "DAH",
        "Formula": "C9H11NO4",
        "Letter": "Ṍ",
        "MolWeight": 197.068807832,
        "SMILES": "N[C@@H](Cc1ccc(c(c1)O)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3,5-dibromotyrosine": {
        "Code": "DBY",
        "Formula": "C9H9Br2NO3",
        "Letter": "Ṏ",
        "MolWeight": 336.894917348,
        "SMILES": "N[C@@H](Cc1cc(Br)c(c(c1)Br)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3,3-dihydroxy-alanine": {
        "Code": "DDZ",
        "Formula": "C3H7NO4",
        "Letter": "Ṑ",
        "MolWeight": 121.037507704,
        "SMILES": "N[C@@H](C(O)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@@H](C(O)O*)C(=O)O",
        "nterm": False,
    },
    "Diethylalanine": {
        "Code": "DILE",
        "Formula": "C7H15NO2",
        "Letter": "Ṓ",
        "MolWeight": 145.11027872,
        "SMILES": "N[C@@H](C(CC)CC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3,3-diphenylalanine": {
        "Code": "DIPH",
        "Formula": "C15H15NO2",
        "Letter": "Ṕ",
        "MolWeight": 241.11027872,
        "SMILES": "N[C@@H]([C@H](c1ccccc1)c1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3,3-dimethyl-aspartic-acid": {
        "Code": "DMK",
        "Formula": "C6H11NO4",
        "Letter": "Ṗ",
        "MolWeight": 161.068807832,
        "SMILES": "N[C@@H](C(C(=O)O)(C)C)C(=O)O",
        "cterm": "N[C@@H](C(C*(=O))(C)C)C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-ethyl-phenylalanine": {
        "Code": "DMP3",
        "Formula": "C11H15NO2",
        "Letter": "Ṙ",
        "MolWeight": 193.11027872,
        "SMILES": "N[C@@H](Cc1cc(CC)ccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2,3-Diaminopropanoic-acid": {
        "Code": "DPP",
        "Formula": "C3H8N2O2",
        "Letter": "Ṛ",
        "MolWeight": 104.058577496,
        "SMILES": "N[C@@H](CN)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CN*)C(=O)O",
    },
    "Ethionine": {
        "Code": "ESC",
        "Formula": "C6H13NO2S",
        "Letter": "Ṝ",
        "MolWeight": 163.066699656,
        "SMILES": "N[C@@H](CCSCC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3,4-Difluoro-phenylalanine": {
        "Code": "F2F",
        "Formula": "C9H9F2NO2",
        "Letter": "Ṟ",
        "MolWeight": 201.060134968,
        "SMILES": "N[C@@H](Cc1ccc(c(c1)F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-chloro-Phenylalanine": {
        "Code": "FCL",
        "Formula": "C9H10ClNO2",
        "Letter": "Ṡ",
        "MolWeight": 199.04000624,
        "SMILES": "N[C@@H](Cc1cccc(c1)Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-Fluoro-glutamic-acid": {
        "Code": "FGA4",
        "Formula": "C5H8FNO4",
        "Letter": "Ṣ",
        "MolWeight": 165.043735956,
        "SMILES": "N[C@@H](C[C@H](F)C(=O)O)C(=O)O",
        "cterm": "N[C@@H](C[C@H](F)C*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-amino-propanedioic-acid": {
        "Code": "FGL",
        "Formula": "C3H5NO4",
        "Letter": "ẟ",
        "MolWeight": 119.02185764000001,
        "SMILES": "NC(C(=O)O)C(=O)O",
        "cterm": "NC(C*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Trifluoro-alanine": {
        "Code": "FLA",
        "Formula": "C3H4F3NO2",
        "Letter": "Ṧ",
        "MolWeight": 143.019413028,
        "SMILES": "N[C@@H](C(F)(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-Fluoro-phenylglycine": {
        "Code": "FPG2",
        "Formula": "C8H8FNO2",
        "Letter": "Ṩ",
        "MolWeight": 169.053906716,
        "SMILES": "N[C@@H](c1ccccc1F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-Fluoro-phenylglycine": {
        "Code": "FPG3",
        "Formula": "C8H8FNO2",
        "Letter": "Ṫ",
        "MolWeight": 169.053906716,
        "SMILES": "N[C@@H](c1cccc(c1)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-Fluoro-phenylglycine": {
        "Code": "FPG4",
        "Formula": "C8H8FNO2",
        "Letter": "Ṭ",
        "MolWeight": 169.053906716,
        "SMILES": "N[C@@H](c1ccc(cc1)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-Fluoro-Phenylalanine": {
        "Code": "FPH2",
        "Formula": "C9H10FNO2",
        "Letter": "Ṯ",
        "MolWeight": 183.06955678,
        "SMILES": "N[C@@H](Cc1ccccc1F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-Fluoro-Phenylalanine": {
        "Code": "FPH3",
        "Formula": "C9H10FNO2",
        "Letter": "Ṱ",
        "MolWeight": 183.06955678,
        "SMILES": "N[C@@H](Cc1cccc(c1)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "6-fluoro-l-tryptophan": {
        "Code": "FT6",
        "Formula": "C11H11FN2O2",
        "Letter": "Ụ",
        "MolWeight": 222.080455812,
        "SMILES": "N[C@@H](Cc1cNc2c1ccc(c2)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "5-Fluoro-tryptophan": {
        "Code": "FTR",
        "Formula": "C11H11FN2O2",
        "Letter": "Ủ",
        "MolWeight": 222.080455812,
        "SMILES": "N[C@@H](Cc1c[nH]c2c1cc(F)cc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "(2-furyl)-alanine": {
        "Code": "FUA2",
        "Formula": "C7H9NO3",
        "Letter": "Ứ",
        "MolWeight": 155.058243148,
        "SMILES": "N[C@@H](Cc1ccco1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-Fluoro-valine": {
        "Code": "FVAL",
        "Formula": "C5H10FNO2",
        "Letter": "Ừ",
        "MolWeight": 135.06955678,
        "SMILES": "N[C@@H](C(F)(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-Amino-4-guanidinobutryric-acid": {
        "Code": "GBUT",
        "Formula": "C5H14N4O2",
        "Letter": "Ử",
        "MolWeight": 162.111675688,
        "SMILES": "N[C@@H](CCNC(N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CCNC(N*)N)C(=O)O",
    },
    "2-Amino-3-guanidinopropionic-acid": {
        "Code": "GDPR",
        "Formula": "C4H12N4O2",
        "Letter": "Ữ",
        "MolWeight": 148.096025624,
        "SMILES": "N[C@@H](CNC(N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CNC(N*)N)C(=O)O",
    },
    "Canavanine": {
        "Code": "GGB",
        "Formula": "C5H12N4O3",
        "Letter": "Ự",
        "MolWeight": 176.090940244,
        "SMILES": "N[C@@H](CCON=C(N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CCON=C(N*)N)C(=O)O",
    },
    "(2s,4s)-2,5-diamino-4-hydroxy-5-oxopentanoic-acid": {
        "Code": "GHG",
        "Formula": "C5H10N2O4",
        "Letter": "Ṳ",
        "MolWeight": 162.0640568,
        "SMILES": "N[C@@H](C[C@H](O)C(=O)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](C[C@H](O)C(=O)N*)C(=O)O",
    },
    "5-o-methyl-glutamic-acid": {
        "Code": "GME",
        "Formula": "C6H11NO4",
        "Letter": "Ṵ",
        "MolWeight": 161.068807832,
        "SMILES": "N[C@@H](CCC(=O)OC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "homocysteine": {
        "Code": "HCS",
        "Formula": "C4H9NO2S",
        "Letter": "Ṷ",
        "MolWeight": 135.035399528,
        "SMILES": "N[C@@H](CCS)C(=O)O",
        "cterm": False,
        "disulphide": "N[C@@H](CCS*)C(=O)O",
        "ester": False,
        "nterm": False,
    },
    "glutamine-hydroxamate": {
        "Code": "HGA",
        "Formula": "C5H10N2O4",
        "Letter": "Ṹ",
        "MolWeight": 162.0640568,
        "SMILES": "N[C@@H](CCC(=O)NO)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "(2s)-2,8-diaminooctanoic-acid": {
        "Code": "HHK",
        "Formula": "C8H18N2O2",
        "Letter": "Ṻ",
        "MolWeight": 174.136827816,
        "SMILES": "N[C@@H](CCCCCCN)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CCCCCCN*)C(=O)O",
    },
    "4-Hydroxy-L-isoleucine": {
        "Code": "HIL4",
        "Formula": "C6H13NO3",
        "Letter": "Ṽ",
        "MolWeight": 147.089543276,
        "SMILES": "N[C@@H]([C@H]([C@@H](C)O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "(2s,3r)-2-amino-3-hydroxy-4-methylpentanoic-acid": {
        "Code": "HL2",
        "Formula": "C6H13NO3",
        "Letter": "Ṿ",
        "MolWeight": 147.089543276,
        "SMILES": "N[C@@H]([C@H](O)C(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Homoleucine": {
        "Code": "HLEU",
        "Formula": "C7H15NO2",
        "Letter": "Ẁ",
        "MolWeight": 145.11027872,
        "SMILES": "N[C@@H](CCC(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "beta-hydroxyleucine": {
        "Code": "HLU",
        "Formula": "C6H13NO3",
        "Letter": "Ẃ",
        "MolWeight": 147.089543276,
        "SMILES": "N[C@@H]([C@@H](O)C(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-amino-L-phenylalanine": {
        "Code": "HOX",
        "Formula": "C9H12N2O2",
        "Letter": "Ẅ",
        "MolWeight": 180.089877624,
        "SMILES": "N[C@@H](Cc1ccc(cc1)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](Cc1ccc(cc1)N*)C(=O)O",
    },
    "Homophenylalanine": {
        "Code": "HPE",
        "Formula": "C10H13NO2",
        "Letter": "Ẇ",
        "MolWeight": 179.094628656,
        "SMILES": "N[C@@H](CCc1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(8-hydroxyquinolin-3-yl)-l-alanine": {
        "Code": "HQA",
        "Formula": "C12H12N2O3",
        "Letter": "Ẉ",
        "MolWeight": 232.084792244,
        "SMILES": "N[C@@H](Cc1cnc2c(c1)cccc2O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "homoarginine": {
        "Code": "HRG",
        "Formula": "C7H18N4O2",
        "Letter": "Ẋ",
        "MolWeight": 190.142975816,
        "SMILES": "N[C@@H](CCCCNC(N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CCCCNC(N*)N)C(=O)O",
    },
    "5-Hydroxy-tryptophan": {
        "Code": "HRP",
        "Formula": "C11H12N2O3",
        "Letter": "Ẍ",
        "MolWeight": 220.084792244,
        "SMILES": "N[C@@H](Cc1cNc2c1cc(O)cc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "homoserine": {
        "Code": "HSER",
        "Formula": "C4H9NO3",
        "Letter": "Ỳ",
        "MolWeight": 119.058243148,
        "SMILES": "N[C@@H](CCO)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@@H](CCO*)C(=O)O",
        "nterm": False,
    },
    "beta-hydroxy-tryptophane": {
        "Code": "HTR",
        "Formula": "C11H12N2O3",
        "Letter": "Ỵ",
        "MolWeight": 220.084792244,
        "SMILES": "N[C@@H]([C@H](c1c[nH]c2c1cccc2)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-hydroxy-l-valine": {
        "Code": "HVA",
        "Formula": "C5H11NO3",
        "Letter": "Ỷ",
        "MolWeight": 133.073893212,
        "SMILES": "N[C@@H](C(O)(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@@H](C(O*)(C)C)C(=O)O",
        "nterm": False,
    },
    "3-methyl-l-alloisoleucine": {
        "Code": "I2M",
        "Formula": "C7H15NO2",
        "Letter": "Ỹ",
        "MolWeight": 145.11027872,
        "SMILES": "N[C@@H](C(CC)(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "alpha-amino-2-indanacetic-acid": {
        "Code": "IGL",
        "Formula": "C11H13NO2",
        "Letter": "Ẏ",
        "MolWeight": 191.094628656,
        "SMILES": "N[C@@H](C1Cc2c(C1)cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Allo-Isoleucine": {
        "Code": "IIL",
        "Formula": "C6H13NO2",
        "Letter": "Ẑ",
        "MolWeight": 131.094628656,
        "SMILES": "N[C@@H]([C@@H](CC)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4,5-dihydroxy-isoleucine": {
        "Code": "ILX",
        "Formula": "C6H13NO4",
        "Letter": "Ẓ",
        "MolWeight": 163.084457896,
        "SMILES": "N[C@@H]([C@H]([C@H](CO)O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@@H]([C@H]([C@H](CO*)O)C)C(=O)O",
        "nterm": False,
    },
    "3-iodo-tyrosine": {
        "Code": "IYR",
        "Formula": "C9H10INO3",
        "Letter": "Ẕ",
        "MolWeight": 306.97054117999994,
        "SMILES": "N[C@@H](Cc1ccc(c(c1)I)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "kynurenine": {
        "Code": "KYN",
        "Formula": "C10H12N2O3",
        "Letter": "Ỻ",
        "MolWeight": 208.084792244,
        "SMILES": "N[C@@H](CC(=O)c1ccccc1N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CC(=O)c1ccccc1N*)C(=O)O",
    },
    "6-hydroxy-l-norleucine": {
        "Code": "LDO",
        "Formula": "C6H13NO3",
        "Letter": "Ỽ",
        "MolWeight": 147.089543276,
        "SMILES": "N[C@@H](CCCCO)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@@H](CCCCO*)C(=O)O",
        "nterm": False,
    },
    "Penicillamine": {
        "Code": "LE1",
        "Formula": "C5H11NO2S",
        "Letter": "Ỿ",
        "MolWeight": 149.051049592,
        "SMILES": "N[C@@H](C(S)(C)C)C(=O)O",
        "cterm": False,
        "disulphide": "N[C@@H](C(S*)(C)C)C(=O)O",
        "ester": False,
        "nterm": False,
    },
    "(4r)-5-oxo-l-leucine": {
        "Code": "LED",
        "Formula": "C6H11NO3",
        "Letter": "Ÿ",
        "MolWeight": 145.073893212,
        "SMILES": "N[C@@H](C[C@@H](C)C=O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "(4s)-5-fluoro-l-leucine": {
        "Code": "LEF",
        "Formula": "C6H12FNO2",
        "Letter": "Ý",
        "MolWeight": 149.085206844,
        "SMILES": "N[C@@H](C[C@H](C)CF)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "(3r)-3-methyl-l-glutamic-acid": {
        "Code": "LME",
        "Formula": "C6H11NO4",
        "Letter": "Ā",
        "MolWeight": 161.068807832,
        "SMILES": "N[C@@H]([C@H](C)CC(=O)O)C(=O)O",
        "cterm": "N[C@@H]([C@H](C)CC*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-methyl-l-glutamine": {
        "Code": "LMQ",
        "Formula": "C6H12N2O3",
        "Letter": "Ă",
        "MolWeight": 160.084792244,
        "SMILES": "N[C@@H]([C@@H](C)CC(N)=O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "vinylglycine": {
        "Code": "LVG",
        "Formula": "C4H7NO2",
        "Letter": "Ą",
        "MolWeight": 101.047678464,
        "SMILES": "N[C@@H](C=C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-oxo-l-valine": {
        "Code": "LVN",
        "Formula": "C5H9NO3",
        "Letter": "Ć",
        "MolWeight": 131.058243148,
        "SMILES": "N[C@@H]([C@H](C)C=O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3,3-dimethyl-methionine-sulfoxide": {
        "Code": "M2S",
        "Formula": "C7H15NO3S",
        "Letter": "Ĉ",
        "MolWeight": 193.07726434,
        "SMILES": "N[C@@H](C(C)(C)C[S@@](C)=O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "hydroxy-l-methionine": {
        "Code": "ME0",
        "Formula": "C5H11NO3S",
        "Letter": "Ċ",
        "MolWeight": 165.045964212,
        "SMILES": "N[C@@H](CCSCO)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@@H](CCSCO*)C(=O)O",
        "nterm": False,
    },
    "(3s)-3-methyl-l-glutamic-acid": {
        "Code": "MEG",
        "Formula": "C6H11NO4",
        "Letter": "Č",
        "MolWeight": 161.068807832,
        "SMILES": "N[C@@H]([C@@H](C)CC(=O)O)C(=O)O",
        "cterm": "N[C@@H]([C@@H](C)CC*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "n-methyl-asparagine": {
        "Code": "MEN",
        "Formula": "C5H10N2O3",
        "Letter": "Ď",
        "MolWeight": 146.06914218,
        "SMILES": "N[C@@H](CC(=O)NC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "n5-methyl-glutamine": {
        "Code": "MEQ",
        "Formula": "C6H12N2O3",
        "Letter": "Đ",
        "MolWeight": 160.084792244,
        "SMILES": "N[C@@H](CCC(=O)NC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "s-oxymethionine": {
        "Code": "MHO",
        "Formula": "C5H11NO3S",
        "Letter": "Ē",
        "MolWeight": 165.045964212,
        "SMILES": "N[C@@H](CC[S@](=O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "5-Methoxy-tryptophan": {
        "Code": "MOT5",
        "Formula": "C12H14N2O3",
        "Letter": "Ĕ",
        "MolWeight": 234.100442308,
        "SMILES": "N[C@@H](Cc1cNc2ccc(OC)cc12)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3,4-Dimethyl-phenylalanine": {
        "Code": "MP34",
        "Formula": "C11H15NO2",
        "Letter": "Ė",
        "MolWeight": 193.11027872,
        "SMILES": "N[C@@H](Cc1ccc(c(c1)C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-Methyl-phenylalanine": {
        "Code": "MPH2",
        "Formula": "C10H13NO2",
        "Letter": "Ę",
        "MolWeight": 179.094628656,
        "SMILES": "N[C@@H](Cc1ccccc1C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "5-Methyl-tryptophan": {
        "Code": "MTR5",
        "Formula": "C12H14N2O2",
        "Letter": "Ě",
        "MolWeight": 218.105527688,
        "SMILES": "N[C@@H](Cc1cNc2ccc(C)cc12)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "6-Methyl-tryptophan": {
        "Code": "MTR6",
        "Formula": "C12H14N2O2",
        "Letter": "Ĝ",
        "MolWeight": 218.105527688,
        "SMILES": "N[C@@H](Cc1cNc2c1ccc(c2)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "m-Tyrosine": {
        "Code": "MTY",
        "Formula": "C9H11NO3",
        "Letter": "Ğ",
        "MolWeight": 181.073893212,
        "SMILES": "N[C@@H](Cc1cccc(c1)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-Naphthyl-alanine": {
        "Code": "NAL",
        "Formula": "C13H13NO2",
        "Letter": "Ġ",
        "MolWeight": 215.094628656,
        "SMILES": "N[C@@H](Cc1ccc2c(c1)cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "5-hydroxy-1-naphthalene": {
        "Code": "NAO1",
        "Formula": "C13H13NO3",
        "Letter": "Ģ",
        "MolWeight": 231.089543276,
        "SMILES": "N[C@@H](Cc1cccc2c1cc(O)cc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "6-hydroxy-2-naphthalene": {
        "Code": "NAO2",
        "Formula": "C13H13NO3",
        "Letter": "Ĥ",
        "MolWeight": 231.089543276,
        "SMILES": "N[C@@H](Cc1ccc2c(c1)cc(cc2)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "meta-nitro-tyrosine": {
        "Code": "NIY",
        "Formula": "C9H10N2O5",
        "Letter": "Ħ",
        "MolWeight": 226.05897142,
        "SMILES": "N[C@@H](Cc1ccc(c(c1)N(=O)=O)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Norleucine": {
        "Code": "NLE",
        "Formula": "C6H13NO2",
        "Letter": "Ĩ",
        "MolWeight": 131.094628656,
        "SMILES": "N[C@@H](CCCC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Norvaline": {
        "Code": "NVA",
        "Formula": "C5H11NO2",
        "Letter": "Ī",
        "MolWeight": 117.078978592,
        "SMILES": "N[C@@H](CCC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "o-acetylserine": {
        "Code": "OAS",
        "Formula": "C5H9NO4",
        "Letter": "Ĭ",
        "MolWeight": 147.053157768,
        "SMILES": "N[C@@H](COC(=O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "(2s)-2-amino-4,4-difluorobutanoic-acid": {
        "Code": "OBF",
        "Formula": "C4H7F2NO2",
        "Letter": "Į",
        "MolWeight": 139.044484904,
        "SMILES": "N[C@@H](CC(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "s-(2-hydroxyethyl)-l-cysteine": {
        "Code": "OCY",
        "Formula": "C5H11NO3S",
        "Letter": "Þ",
        "MolWeight": 165.045964212,
        "SMILES": "N[C@@H](CSCCO)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@@H](CSCCO*)C(=O)O",
        "nterm": False,
    },
    "o-methyl-l-threonine": {
        "Code": "OLT",
        "Formula": "C5H11NO3",
        "Letter": "Ĳ",
        "MolWeight": 133.073893212,
        "SMILES": "N[C@@H]([C@H](OC)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Methionine-sulfone": {
        "Code": "OMT",
        "Formula": "C5H11NO4S",
        "Letter": "Ĵ",
        "MolWeight": 181.040878832,
        "SMILES": "N[C@@H](CCS(=O)(=O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "(betar)-beta-hydroxy-l-tyrosine": {
        "Code": "OMX",
        "Formula": "C9H11NO4",
        "Letter": "Ķ",
        "MolWeight": 197.068807832,
        "SMILES": "N[C@@H]([C@@H](c1ccc(cc1)O)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "(betar)-3-chloro-beta-hydroxy-l-tyrosine": {
        "Code": "OMY",
        "Formula": "C9H10ClNO4",
        "Letter": "Ĺ",
        "MolWeight": 231.02983548,
        "SMILES": "N[C@@H]([C@@H](c1ccc(c(c1)Cl)O)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "5-oxo-l-norleucine": {
        "Code": "ONL",
        "Formula": "C6H11NO3",
        "Letter": "Ļ",
        "MolWeight": 145.073893212,
        "SMILES": "N[C@@H](CCC(=O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Ornithine": {
        "Code": "ORN",
        "Formula": "C5H12N2O2",
        "Letter": "Ľ",
        "MolWeight": 132.089877624,
        "SMILES": "N[C@@H](CCCN)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CCCN*)C(=O)O",
    },
    "o-Tyrosine": {
        "Code": "OTYR",
        "Formula": "C9H11NO3",
        "Letter": "Ŀ",
        "MolWeight": 181.073893212,
        "SMILES": "N[C@@H](Cc1ccccc1O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-benzoyl-phenylalanine": {
        "Code": "PBF",
        "Formula": "C16H15NO3",
        "Letter": "Ł",
        "MolWeight": 269.10519334,
        "SMILES": "N[C@@H](Cc1ccc(cc1)C(=O)c1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "pentafluoro-phenylalanine": {
        "Code": "PF5",
        "Formula": "C9H6F5NO2",
        "Letter": "Ń",
        "MolWeight": 255.031869532,
        "SMILES": "N[C@@H](Cc1c(F)c(F)c(c(c1F)F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-Fluoro-Phenylalanine": {
        "Code": "PFF",
        "Formula": "C9H10FNO2",
        "Letter": "Ņ",
        "MolWeight": 183.06955678,
        "SMILES": "N[C@@H](Cc1ccc(cc1)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-Iodo-Phenylalanine": {
        "Code": "PHI",
        "Formula": "C9H10INO2",
        "Letter": "Ň",
        "MolWeight": 290.97562655999997,
        "SMILES": "N[C@@H](Cc1ccc(cc1)I)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-Nitro-phenylalanine": {
        "Code": "PPN",
        "Formula": "C9H10N2O4",
        "Letter": "Ŋ",
        "MolWeight": 210.0640568,
        "SMILES": "N[C@@H](Cc1ccc(cc1)N(=O)=O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "phosphotyrosine": {
        "Code": "PTR",
        "Formula": "C9H12NO6P",
        "Letter": "Ō",
        "MolWeight": 261.04022373400005,
        "SMILES": "N[C@@H](Cc1ccc(cc1)OP(=O)(O)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(2-Pyridyl)-alanine": {
        "Code": "PYR2",
        "Formula": "C8H10N2O2",
        "Letter": "Ŏ",
        "MolWeight": 166.07422756,
        "SMILES": "N[C@@H](Cc1ccccn1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(3-Pyridyl)-alanine": {
        "Code": "PYR3",
        "Formula": "C8H10N2O2",
        "Letter": "Ő",
        "MolWeight": 166.07422756,
        "SMILES": "N[C@@H](Cc1cccnc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(4-Pyridyl)-alanine": {
        "Code": "PYR4",
        "Formula": "C8H10N2O2",
        "Letter": "Œ",
        "MolWeight": 166.07422756,
        "SMILES": "N[C@@H](Cc1ccncc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(1-Pyrazolyl)-alanine": {
        "Code": "PYZ1",
        "Formula": "C6H9N3O2",
        "Letter": "Ŕ",
        "MolWeight": 155.069476528,
        "SMILES": "N[C@@H](Cn1cccn1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(2-Quinolyl)-alanine": {
        "Code": "QU32",
        "Formula": "C12H12N2O2",
        "Letter": "Ŗ",
        "MolWeight": 216.089877624,
        "SMILES": "N[C@@H](Cc1ccc2c(n1)cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(3-quinolyl)-alanine": {
        "Code": "QU33",
        "Formula": "C12H12N2O2",
        "Letter": "Ř",
        "MolWeight": 216.089877624,
        "SMILES": "N[C@@H](Cc1cnc2c(c1)cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(4-quinolyl)-alanine": {
        "Code": "QU34",
        "Formula": "C12H12N2O2",
        "Letter": "Ś",
        "MolWeight": 216.089877624,
        "SMILES": "N[C@@H](Cc1ccnc2c1cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(5-Quinolyl)-alanine": {
        "Code": "QU35",
        "Formula": "C12H12N2O2",
        "Letter": "Ŝ",
        "MolWeight": 216.089877624,
        "SMILES": "N[C@@H](Cc1ccc2c(c1)nccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(6-Quinolyl)-alanine": {
        "Code": "QU36",
        "Formula": "C12H12N2O2",
        "Letter": "Ş",
        "MolWeight": 216.089877624,
        "SMILES": "N[C@@H](Cc1ccc2c(c1)cncc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(2-quinoxalyl)-alanine": {
        "Code": "QX32",
        "Formula": "C11H11N3O2",
        "Letter": "Š",
        "MolWeight": 217.085126592,
        "SMILES": "N[C@@H](Cc1cnc2c(n1)cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "phosphoserine": {
        "Code": "SEP",
        "Formula": "C3H8NO6P",
        "Letter": "Ţ",
        "MolWeight": 185.008923606,
        "SMILES": "N[C@@H](COP(=O)(O)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "thialysine": {
        "Code": "SLZ",
        "Formula": "C5H12N2O2S",
        "Letter": "Ť",
        "MolWeight": 164.061948624,
        "SMILES": "N[C@@H](CSCCN)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CSCCN*)C(=O)O",
    },
    "Methionine-sulfoxide": {
        "Code": "SME",
        "Formula": "C5H11NO3S",
        "Letter": "Ŧ",
        "MolWeight": 165.045964212,
        "SMILES": "N[C@@H](CC[S@](=O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Styrylalanine": {
        "Code": "STYA",
        "Formula": "C11H13NO2",
        "Letter": "Ũ",
        "MolWeight": 191.094628656,
        "SMILES": "N[C@@H](CC=Cc1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2s,4r-4-methylglutamate": {
        "Code": "SYM",
        "Formula": "C6H11NO4",
        "Letter": "Ū",
        "MolWeight": 161.068807832,
        "SMILES": "N[C@@H](C[C@H](C(=O)O)C)C(=O)O",
        "cterm": "N[C@@H](C[C@H](C*(=O))C)C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-tert-butyl-phenylalanine": {
        "Code": "TBP4",
        "Formula": "C13H19NO2",
        "Letter": "Ŭ",
        "MolWeight": 221.141578848,
        "SMILES": "N[C@@H](Cc1ccc(cc1)C(C)(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(2-Tetrazolyl)-alanine": {
        "Code": "TEZA",
        "Formula": "C4H7N5O2",
        "Letter": "Ů",
        "MolWeight": 157.059974464,
        "SMILES": "N[C@@H](Cn1nncn1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-(Trifluoromethyl)-phenylglycine": {
        "Code": "TFG2",
        "Formula": "C9H8F3NO2",
        "Letter": "Ű",
        "MolWeight": 219.050713156,
        "SMILES": "N[C@@H](c1ccccc1C(F)(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(Trifluoromethyl)-phenylglycine": {
        "Code": "TFG3",
        "Formula": "C9H8F3NO2",
        "Letter": "Ų",
        "MolWeight": 219.050713156,
        "SMILES": "N[C@@H](c1cccc(c1)C(F)(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-(Trifluoromethyl)-phenylglycine": {
        "Code": "TFG4",
        "Formula": "C9H8F3NO2",
        "Letter": "Ŵ",
        "MolWeight": 219.050713156,
        "SMILES": "N[C@@H](c1ccc(cc1)C(F)(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "5,5,5-Trifluoro-leucine": {
        "Code": "TFLE",
        "Formula": "C6H10F3NO2",
        "Letter": "Ŷ",
        "MolWeight": 185.06636322,
        "SMILES": "N[C@@H](C[C@@H](C(F)(F)F)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-(Trifluoromethyl)-phenylalanine": {
        "Code": "TFP2",
        "Formula": "C10H10F3NO2",
        "Letter": "Ź",
        "MolWeight": 233.06636322,
        "SMILES": "N[C@@H](Cc1ccccc1C(F)(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(Trifluoromethyl)-phenylalanine": {
        "Code": "TFP3",
        "Formula": "C10H10F3NO2",
        "Letter": "Ż",
        "MolWeight": 233.06636322,
        "SMILES": "N[C@@H](Cc1cccc(c1)C(F)(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-(Trifluoromethyl)-phenylalanine": {
        "Code": "TFP4",
        "Formula": "C10H10F3NO2",
        "Letter": "Ž",
        "MolWeight": 233.06636322,
        "SMILES": "N[C@@H](Cc1ccc(cc1)C(F)(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "4-hydroxy-l-threonine": {
        "Code": "TH6",
        "Formula": "C4H9NO4",
        "Letter": "À",
        "MolWeight": 135.053157768,
        "SMILES": "N[C@@H]([C@H](O)CO)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@@H]([C@H](O)CO*)C(=O)O",
        "nterm": False,
    },
    "3-(3-thienyl)-alanine": {
        "Code": "THA3",
        "Formula": "C7H9NO2S",
        "Letter": "Á",
        "MolWeight": 171.035399528,
        "SMILES": "N[C@@H](Cc1cscc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-thienylglycine": {
        "Code": "THG2",
        "Formula": "C6H7NO2S",
        "Letter": "Â",
        "MolWeight": 157.019749464,
        "SMILES": "N[C@@H](c1cccs1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-thienylglycine": {
        "Code": "THG3",
        "Formula": "C6H7NO2S",
        "Letter": "Ã",
        "MolWeight": 157.019749464,
        "SMILES": "N[C@@H](c1cscc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Thio-citrulline": {
        "Code": "THIC",
        "Formula": "C6H13N3O2S",
        "Letter": "Ä",
        "MolWeight": 191.072847656,
        "SMILES": "N[C@@H](CCCNC(=S)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CCCNC(=S)N*)C(=O)O",
    },
    "3-(2-thienyl)-alanine": {
        "Code": "TIH",
        "Formula": "C7H9NO2S",
        "Letter": "Å",
        "MolWeight": 171.035399528,
        "SMILES": "N[C@@H](Cc1cccs1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "phosphothreonine": {
        "Code": "TPO",
        "Formula": "C4H10NO6P",
        "Letter": "Æ",
        "MolWeight": 199.02457367,
        "SMILES": "N[C@@H]([C@H](OP(=O)(O)O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-hydroxy-tryptophan": {
        "Code": "TRO",
        "Formula": "C11H12N2O3",
        "Letter": "Ç",
        "MolWeight": 220.084792244,
        "SMILES": "N[C@@H](Cc1c(O)[nH]c2c1cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "6-hydroxy-tryptophan": {
        "Code": "TRX",
        "Formula": "C11H12N2O3",
        "Letter": "È",
        "MolWeight": 220.084792244,
        "SMILES": "N[C@@H](Cc1c[nH]c2c1ccc(c2)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-(1,2,4-Triazol-1-yl)-alanine": {
        "Code": "TRZ4",
        "Formula": "C5H8N4O2",
        "Letter": "É",
        "MolWeight": 156.064725496,
        "SMILES": "N[C@@H](Cn1cncn1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "6-amino-7-hydroxy-l-tryptophan": {
        "Code": "TTQ",
        "Formula": "C11H13N3O3",
        "Letter": "Ê",
        "MolWeight": 235.095691276,
        "SMILES": "N[C@@H](Cc1c[nH]c2c1ccc(c2O)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](Cc1c[nH]c2c1ccc(c2O)N*)C(=O)O",
    },
    "3-Amino-L-tyrosine": {
        "Code": "TY2",
        "Formula": "C9H12N2O3",
        "Letter": "Ë",
        "MolWeight": 196.084792244,
        "SMILES": "N[C@@H](Cc1ccc(c(c1)N)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3,5-diiodotyrosine": {
        "Code": "TYI",
        "Formula": "C9H9I2NO3",
        "Letter": "Ì",
        "MolWeight": 432.8671891479999,
        "SMILES": "N[C@@H](Cc1cc(I)c(c(c1)I)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3-amino-6-hydroxy-tyrosine": {
        "Code": "TYQ",
        "Formula": "C9H12N2O4",
        "Letter": "Í",
        "MolWeight": 212.079706864,
        "SMILES": "N[C@@H](Cc1cc(N)c(cc1O)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "(4-thiazolyl)-alanine": {
        "Code": "TZA4",
        "Formula": "C6H8N2O2S",
        "Letter": "Î",
        "MolWeight": 172.030648496,
        "SMILES": "N[C@@H](Cc1cscn1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "2-Aminoadipic-acid": {
        "Code": "UN1",
        "Formula": "C6H11NO4",
        "Letter": "Ï",
        "MolWeight": 161.068807832,
        "SMILES": "N[C@@H](CCCC(=O)O)C(=O)O",
        "cterm": "N[C@@H](CCCC*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Hydroxynorvaline": {
        "Code": "VAH",
        "Formula": "C5H11NO3",
        "Letter": "Ð",
        "MolWeight": 133.073893212,
        "SMILES": "N[C@@H]([C@H](O)CC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "3,5-Difluoro-phenylalanine": {
        "Code": "WFP",
        "Formula": "C9H9F2NO2",
        "Letter": "Ñ",
        "MolWeight": 201.060134968,
        "SMILES": "N[C@@H](Cc1cc(F)cc(c1)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "cysteine-s-acetamide": {
        "Code": "YCM",
        "Formula": "C5H10N2O3S",
        "Letter": "Ò",
        "MolWeight": 178.04121318,
        "SMILES": "N[C@@H](CSCC(=O)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CSCC(=O)N*)C(=O)O",
    },
    "3-fluorotyrosine": {
        "Code": "YOF",
        "Formula": "C9H10FNO3",
        "Letter": "Ó",
        "MolWeight": 199.0644714,
        "SMILES": "N[C@@H](Cc1ccc(c(c1)F)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Phenylglycine": {
        "Code": "DPG",
        "Formula": "C8H9NO2",
        "Letter": "ḁ",
        "MolWeight": 151.063328528,
        "SMILES": "N[C@H](c1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-methoxy-Phenylalanine": {
        "Code": "D0A1",
        "Formula": "C10H13NO3",
        "Letter": "ạ",
        "MolWeight": 195.089543276,
        "SMILES": "N[C@H](Cc1ccc(OC)cc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-7-hydroxy-l-tryptophan": {
        "Code": "D0AF",
        "Formula": "C11H12N2O3",
        "Letter": "ả",
        "MolWeight": 220.084792244,
        "SMILES": "N[C@H](Cc1c[nH]c2c1cccc2O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-carbamimidoyl-l-phenylalanine": {
        "Code": "D0BN",
        "Formula": "C10H13N3O2",
        "Letter": "ấ",
        "MolWeight": 207.100776656,
        "SMILES": "N[C@H](Cc1ccc(cc1)C(=N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](Cc1ccc(cc1)C(=N)N*)C(=O)O",
    },
    "d-4-chloro-Phenylalanine": {
        "Code": "D200",
        "Formula": "C9H10ClNO2",
        "Letter": "ầ",
        "MolWeight": 199.04000624,
        "SMILES": "N[C@H](Cc1ccc(cc1)Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-Allyl-glycine": {
        "Code": "D2AG",
        "Formula": "C7H11NO5",
        "Letter": "ẫ",
        "MolWeight": 189.063722452,
        "SMILES": "N[C@H](CCCC(C(=O)O)=O)C(=O)O",
        "cterm": "N[C@H](CCCC(C*(=O))=O)C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-methyl-aspartic-acid": {
        "Code": "D2AS",
        "Formula": "C5H9NO4",
        "Letter": "ậ",
        "MolWeight": 147.053157768,
        "SMILES": "N[C@@H]([C@H](C)(C(=O)O))C(=O)O",
        "cterm": "N[C@@H]([C@H](C)(C*(=O)))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-s-(difluoromethyl)-homocysteine": {
        "Code": "D2FM",
        "Formula": "C5H9F2NO2S",
        "Letter": "ắ",
        "MolWeight": 185.032205968,
        "SMILES": "N[C@H](CCSC(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-fluoro-l-histidine": {
        "Code": "D2HF",
        "Formula": "C6H12FN3O2",
        "Letter": "ằ",
        "MolWeight": 177.091354844,
        "SMILES": "N[C@H](C[C@@H]1CN[C@@H](N1)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-fluoro-l-histidine(1)": {
        "Code": "D2H1",
        "Formula": "C6H8FN3O2",
        "Letter": "ẳ",
        "MolWeight": 173.060054716,
        "SMILES": "N[C@H](Cc1cnc(F)N1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-fluoro-l-histidine(2)": {
        "Code": "D2H2",
        "Formula": "C6H8FN3O2",
        "Letter": "ẵ",
        "MolWeight": 173.060054716,
        "SMILES": "N[C@H](Cc1c[nH]c(n1)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-l-2-amino-6-methylene-pimelic-acid": {
        "Code": "D2NP",
        "Formula": "C8H13NO4",
        "Letter": "ặ",
        "MolWeight": 187.084457896,
        "SMILES": "N[C@H](CCCC(=C)C(=O)O)C(=O)O",
        "cterm": "N[C@H](CCCC(=C)C*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(4H-thieno[3,2-b]pyrrol-6-yl)-L-alanine": {
        "Code": "D32T",
        "Formula": "C9H10N2O2S",
        "Letter": "ḃ",
        "MolWeight": 210.04629856,
        "SMILES": "N[C@@H](Cc1c[nH]c2c1scc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-cyano-phenylalanine": {
        "Code": "D3CF",
        "Formula": "C10H10N2O2",
        "Letter": "ḅ",
        "MolWeight": 190.07422756,
        "SMILES": "N[C@H](Cc1cccc(C#N)c1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-(2s)-amino(3,5-dihydroxyphenyl)-ethanoic-acid": {
        "Code": "D3FG",
        "Formula": "C8H9NO4",
        "Letter": "ḇ",
        "MolWeight": 183.053157768,
        "SMILES": "N[C@H](c1cc(O)cc(c1)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-hydroxy-glutamic-acid": {
        "Code": "D3GL",
        "Formula": "C5H9NO5",
        "Letter": "ḉ",
        "MolWeight": 163.048072388,
        "SMILES": "N[C@H](C[C@@H](C(=O)O)O)C(=O)O",
        "cterm": "N[C@H](C[C@@H](C*(=O))O)C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-Chloro-tyrosine": {
        "Code": "D3MY",
        "Formula": "C9H10ClNO3",
        "Letter": "ḋ",
        "MolWeight": 215.03492086,
        "SMILES": "N[C@@H](Cc1ccc(c(c1)Cl)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-Bromo-phenylalanine": {
        "Code": "D4BF",
        "Formula": "C9H10BrNO2",
        "Letter": "ḍ",
        "MolWeight": 242.98949066,
        "SMILES": "N[C@H](Cc1ccc(cc1)Br)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-cyano-phenylalanine": {
        "Code": "D4CF",
        "Formula": "C10H10N2O2",
        "Letter": "ḏ",
        "MolWeight": 190.07422756,
        "SMILES": "N[C@H](Cc1ccc(cc1)C#N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-nitrilo-l-methionine": {
        "Code": "D4CY",
        "Formula": "C5H8N2O2S",
        "Letter": "ḑ",
        "MolWeight": 160.030648496,
        "SMILES": "N[C@H](CCSC#N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-fluoro-tryptophan": {
        "Code": "D4FW",
        "Formula": "C11H11FN2O2",
        "Letter": "ḓ",
        "MolWeight": 222.080455812,
        "SMILES": "N[C@H](Cc1c[nH]c2c1c(F)ccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-hydroxymethyl-phenylalanine": {
        "Code": "D4HZ",
        "Formula": "C10H13NO3",
        "Letter": "ḕ",
        "MolWeight": 195.089543276,
        "SMILES": "N[C@H](Cc1ccc(CO)cc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-hydroxy-tryptophan": {
        "Code": "D4HT",
        "Formula": "C11H12N2O3",
        "Letter": "ḗ",
        "MolWeight": 220.084792244,
        "SMILES": "N[C@H](Cc1c[nH]c2c1c(O)ccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-amino-l-tryptophan": {
        "Code": "D4IN",
        "Formula": "C11H13N3O2",
        "Letter": "ḙ",
        "MolWeight": 219.100776656,
        "SMILES": "N[C@H](Cc1c[nH]c2c1c(N)ccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-methyl-phenylalanine": {
        "Code": "D4PH",
        "Formula": "C10H13NO2",
        "Letter": "ḛ",
        "MolWeight": 179.094628656,
        "SMILES": "N[C@H](Cc1ccc(cc1)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-6-carboxylysine": {
        "Code": "D6CL",
        "Formula": "C7H14N2O4",
        "Letter": "ḝ",
        "MolWeight": 190.095356928,
        "SMILES": "N[C@H](CCC[C@H](C(=O)O)N)C(=O)O",
        "cterm": "N[C@H](CCC[C@H](C*(=O))N)C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CCC[C@H](C(=O)O)N*)C(=O)O",
    },
    "d-6-chloro-l-tryptophan": {
        "Code": "D6CW",
        "Formula": "C11H11ClN2O2",
        "Letter": "ẹ",
        "MolWeight": 238.050905272,
        "SMILES": "N[C@H](Cc1c[nH]c2c1ccc(c2)Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-amino-5-hydroxypentanoic-acid": {
        "Code": "DAA4",
        "Formula": "C5H11NO3",
        "Letter": "ẻ",
        "MolWeight": 133.073893212,
        "SMILES": "N[C@H](CCCO)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@H](CCCO*)C(=O)O",
        "nterm": False,
    },
    "d-2-Aminobutyric-acid": {
        "Code": "DABA",
        "Formula": "C4H9NO2",
        "Letter": "ẽ",
        "MolWeight": 103.063328528,
        "SMILES": "N[C@H](CC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-cis-amiclenomycin": {
        "Code": "DACZ",
        "Formula": "C10H16N2O2",
        "Letter": "ế",
        "MolWeight": 196.121177752,
        "SMILES": "N[C@H](CC[C@@H]1C=C[C@@H](C=C1)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CC[C@@H]1C=C[C@@H](C=C1)N*)C(=O)O",
    },
    "d-Adamanthane": {
        "Code": "DADM",
        "Formula": "C13H21NO2",
        "Letter": "ề",
        "MolWeight": 223.157228912,
        "SMILES": "N[C@H](C[C@]12C[C@H]3C[C@@H](C2)C[C@@H](C1)C3)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-5-methyl-arginine": {
        "Code": "DAGM",
        "Formula": "C7H16N4O2",
        "Letter": "ể",
        "MolWeight": 188.127325752,
        "SMILES": "N[C@H](CC[C@H](C)NC(=N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CC[C@H](C)NC(=N*)N)C(=O)O",
    },
    "d-beta-hydroxyasparagine": {
        "Code": "DAHB",
        "Formula": "C4H8N2O4",
        "Letter": "ễ",
        "MolWeight": 148.048406736,
        "SMILES": "N[C@H]([C@@H](C(=O)N)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-Aminoheptanoic-acid": {
        "Code": "DAHP",
        "Formula": "C7H15NO2",
        "Letter": "ệ",
        "MolWeight": 145.11027872,
        "SMILES": "N[C@H](CCCCC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-cyclohexyl-alanine": {
        "Code": "DALC",
        "Formula": "C9H17NO2",
        "Letter": "ḟ",
        "MolWeight": 171.125928784,
        "SMILES": "N[C@H](CC1CCCCC1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-1-Naphthyl-alanine": {
        "Code": "DALN",
        "Formula": "C13H13NO2",
        "Letter": "ḡ",
        "MolWeight": 215.094628656,
        "SMILES": "N[C@H](Cc1cccc2c1cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Allo-threonine": {
        "Code": "DALO",
        "Formula": "C4H9NO3",
        "Letter": "ḣ",
        "MolWeight": 119.058243148,
        "SMILES": "N[C@H]([C@H](C)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(9-anthryl)-alanine": {
        "Code": "DNTL",
        "Formula": "C17H15NO2",
        "Letter": "ḥ",
        "MolWeight": 265.11027872,
        "SMILES": "N[C@H](Cc1c2ccccc2cc2c1cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-Methyl-phenylalanine": {
        "Code": "DAPD",
        "Formula": "C10H13NO2",
        "Letter": "ḧ",
        "MolWeight": 179.094628656,
        "SMILES": "N[C@H](Cc1cccc(c1)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-m-amidinophenyl-3-alanine": {
        "Code": "DAPM",
        "Formula": "C10H13N3O2",
        "Letter": "ḩ",
        "MolWeight": 207.100776656,
        "SMILES": "N[C@H](Cc1cccc(c1)C(=N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](Cc1cccc(c1)C(=N*)N)C(=O)O",
    },
    "d-c-gamma-hydroxy-arginine": {
        "Code": "DARO",
        "Formula": "C6H14N4O3",
        "Letter": "ḫ",
        "MolWeight": 190.106590308,
        "SMILES": "N[C@H](C[C@@H](O)CN=C(N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](C[C@@H](O)CN=C(N)N*)C(=O)O",
    },
    "d-(2r)-2-amino-4-oxobutanoic-acid": {
        "Code": "DAS2",
        "Formula": "C4H7NO3",
        "Letter": "ỉ",
        "MolWeight": 117.042593084,
        "SMILES": "N[C@H](CC=O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-azido-alanine": {
        "Code": "DZDA",
        "Formula": "C3H7N4O2+",
        "Letter": "ị",
        "MolWeight": 131.05635188409,
        "SMILES": "N[C@H](CN=[N+]=N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Phenylserine": {
        "Code": "DBB8",
        "Formula": "C9H11NO3",
        "Letter": "ḭ",
        "MolWeight": 181.073893212,
        "SMILES": "N[C@H]([C@@H](O)c1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-benzylcysteine": {
        "Code": "DBCS",
        "Formula": "C10H13NO2S",
        "Letter": "ḯ",
        "MolWeight": 211.066699656,
        "SMILES": "N[C@H](CSCc1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-beta-hydroxyaspartic-acid": {
        "Code": "DBHD",
        "Formula": "C4H7NO5",
        "Letter": "ḱ",
        "MolWeight": 149.032422324,
        "SMILES": "N[C@H]([C@H](O)C(=O)O)C(=O)O",
        "cterm": "N[C@H]([C@H](O)C*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4,4-biphenylalanine": {
        "Code": "DBIF",
        "Formula": "C15H15NO2",
        "Letter": "ḳ",
        "MolWeight": 241.11027872,
        "SMILES": "N[C@H](Cc1ccc(cc1)c1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-5-bromo-l-isoleucine": {
        "Code": "DBIU",
        "Formula": "C6H12BrNO2",
        "Letter": "ḵ",
        "MolWeight": 209.005140724,
        "SMILES": "N[C@H]([C@@H](C)CCBr)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(3-benzothienyl)-alanine": {
        "Code": "DTH9",
        "Formula": "C11H11NO2S",
        "Letter": "ḷ",
        "MolWeight": 221.051049592,
        "SMILES": "N[C@H](Cc1csc2c1cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-6-bromo-tryptophan": {
        "Code": "DBTR",
        "Formula": "C11H11BrN2O2",
        "Letter": "ḹ",
        "MolWeight": 282.000389692,
        "SMILES": "N[C@H](Cc1c[nH]c2c1ccc(c2)Br)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Tertleucine": {
        "Code": "DBUG",
        "Formula": "C6H13NO2",
        "Letter": "ḻ",
        "MolWeight": 131.094628656,
        "SMILES": "N[C@H](C(C)(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-chloro-l-alanine": {
        "Code": "DC2N",
        "Formula": "C3H6ClNO2",
        "Letter": "ḽ",
        "MolWeight": 123.008706112,
        "SMILES": "N[C@H](CCl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-canaline": {
        "Code": "DCAN",
        "Formula": "C4H10N2O3",
        "Letter": "ḿ",
        "MolWeight": 134.06914218,
        "SMILES": "N[C@H](CCON)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-carboxymethylated-cysteine": {
        "Code": "DCCS",
        "Formula": "C5H9NO4S",
        "Letter": "ṁ",
        "MolWeight": 179.025228768,
        "SMILES": "N[C@H](CSCC(=O)O)C(=O)O",
        "cterm": "N[C@H](CSCC*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Cyclohexylglycine": {
        "Code": "DCHG",
        "Formula": "C8H15NO2",
        "Letter": "ṃ",
        "MolWeight": 157.11027872,
        "SMILES": "N[C@H](C1CCCCC1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-chloro-4-hydroxy-phenylglycine": {
        "Code": "DCHP",
        "Formula": "C8H8ClNO3",
        "Letter": "ṅ",
        "MolWeight": 201.019270796,
        "SMILES": "N[C@H](c1ccc(c(c1)Cl)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Citrulline": {
        "Code": "DCIR",
        "Formula": "C6H13N3O3",
        "Letter": "ṇ",
        "MolWeight": 175.095691276,
        "SMILES": "N[C@H](CCC[NH]C(=O)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CCC[NH]C(=O)N*)C(=O)O",
    },
    "d-2-cyano-phenylalanine": {
        "Code": "D2CF",
        "Formula": "C10H10N2O2",
        "Letter": "ṉ",
        "MolWeight": 190.07422756,
        "SMILES": "N[C@H](Cc1ccccc1C#N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2,4-dichloro-phenylalanine": {
        "Code": "D24E",
        "Formula": "C9H9Cl2NO2",
        "Letter": "ṋ",
        "MolWeight": 233.001033888,
        "SMILES": "N[C@H](Cc1ccc(cc1Cl)Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3,4-dichloro-phenylalanine": {
        "Code": "D34E",
        "Formula": "C9H9Cl2NO2",
        "Letter": "ọ",
        "MolWeight": 233.001033888,
        "SMILES": "N[C@H](Cc1ccc(c(c1)Cl)Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-Cyclopentyl-alanine": {
        "Code": "DCPE",
        "Formula": "C8H15NO2",
        "Letter": "ỏ",
        "MolWeight": 157.11027872,
        "SMILES": "N[C@H](CC1CCCC1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-Chloro-phenylglycine": {
        "Code": "DCG6",
        "Formula": "C8H8ClNO2",
        "Letter": "ố",
        "MolWeight": 185.024356176,
        "SMILES": "N[C@H](c1ccccc1Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-Chloro-phenylglycine": {
        "Code": "DCG5",
        "Formula": "C8H8ClNO2",
        "Letter": "ồ",
        "MolWeight": 185.024356176,
        "SMILES": "N[C@H](c1cccc(c1)Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-Chloro-phenylglycine": {
        "Code": "DCGD",
        "Formula": "C8H8ClNO2",
        "Letter": "ổ",
        "MolWeight": 185.024356176,
        "SMILES": "N[C@H](c1ccc(cc1)Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-chloro-Phenylalanine": {
        "Code": "DCF6",
        "Formula": "C9H10ClNO2",
        "Letter": "ỗ",
        "MolWeight": 199.04000624,
        "SMILES": "N[C@H](Cc1ccccc1Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-s-acetonylcysteine": {
        "Code": "DCSA",
        "Formula": "C6H11NO3S",
        "Letter": "ộ",
        "MolWeight": 177.045964212,
        "SMILES": "N[C@H](CSCC(=O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Selenocysteine": {
        "Code": "DCSE",
        "Formula": "C3H7NO2Se",
        "Letter": "ớ",
        "MolWeight": 168.964199764,
        "SMILES": "N[C@H](C[SeH])C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-7-chloro-tryptophan": {
        "Code": "DCTE",
        "Formula": "C11H11ClN2O2",
        "Letter": "ờ",
        "MolWeight": 238.050905272,
        "SMILES": "N[C@H](Cc1cNc2c1cccc2Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-chloro-threonine": {
        "Code": "DCTH",
        "Formula": "C4H8ClNO3",
        "Letter": "ở",
        "MolWeight": 153.019270796,
        "SMILES": "N[C@H]([C@H](O)CCl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-Hydroxy-phenylglycine": {
        "Code": "DD4P",
        "Formula": "C8H9NO3",
        "Letter": "ỡ",
        "MolWeight": 167.058243148,
        "SMILES": "N[C@H](c1ccc(cc1)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Diaminobutyric-acid": {
        "Code": "DDAB",
        "Formula": "C4H10N2O2",
        "Letter": "ợ",
        "MolWeight": 118.07422756,
        "SMILES": "N[C@H](CCN)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CCN*)C(=O)O",
    },
    "d-3,4-Dihydroxy-phenylalanine": {
        "Code": "DDAH",
        "Formula": "C9H11NO4",
        "Letter": "ṍ",
        "MolWeight": 197.068807832,
        "SMILES": "N[C@H](Cc1ccc(c(c1)O)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3,5-dibromotyrosine": {
        "Code": "DDBY",
        "Formula": "C9H9Br2NO3",
        "Letter": "ṏ",
        "MolWeight": 336.894917348,
        "SMILES": "N[C@H](Cc1cc(Br)c(c(c1)Br)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3,3-dihydroxy-alanine": {
        "Code": "DDDZ",
        "Formula": "C3H7NO4",
        "Letter": "ṑ",
        "MolWeight": 121.037507704,
        "SMILES": "N[C@H](C(=O)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](C*(=O))C(=O)O",
    },
    "d-Diethylalanine": {
        "Code": "D2EL",
        "Formula": "C7H15NO2",
        "Letter": "ṓ",
        "MolWeight": 145.11027872,
        "SMILES": "N[C@H](C(CC)CC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3,3-diphenylalanine": {
        "Code": "D2F1",
        "Formula": "C15H15NO2",
        "Letter": "ṕ",
        "MolWeight": 241.11027872,
        "SMILES": "N[C@H]([C@H](c1ccccc1)c1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3,3-dimethyl-aspartic-acid": {
        "Code": "DDMK",
        "Formula": "C6H11NO4",
        "Letter": "ṗ",
        "MolWeight": 161.068807832,
        "SMILES": "N[C@H](C(C(=O)O)(C)C)C(=O)O",
        "cterm": "N[C@H](C(C*(=O))(C)C)C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-ethyl-phenylalanine": {
        "Code": "DDF4",
        "Formula": "C11H15NO2",
        "Letter": "ṙ",
        "MolWeight": 193.11027872,
        "SMILES": "N[C@H](Cc1cc(CC)ccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2,3-Diaminopropanoic-acid": {
        "Code": "DDPP",
        "Formula": "C3H8N2O2",
        "Letter": "ṛ",
        "MolWeight": 104.058577496,
        "SMILES": "N[C@H](CN)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CN*)C(=O)O",
    },
    "d-Ethionine": {
        "Code": "DESC",
        "Formula": "C6H13NO2S",
        "Letter": "ṝ",
        "MolWeight": 163.066699656,
        "SMILES": "N[C@H](CCSCC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3,4-Difluoro-phenylalanine": {
        "Code": "DF2F",
        "Formula": "C9H9F2NO2",
        "Letter": "ṟ",
        "MolWeight": 201.060134968,
        "SMILES": "N[C@H](Cc1ccc(c(c1)F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-chloro-Phenylalanine": {
        "Code": "DFCL",
        "Formula": "C9H10ClNO2",
        "Letter": "ṡ",
        "MolWeight": 199.04000624,
        "SMILES": "N[C@H](Cc1cccc(c1)Cl)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-Fluoro-glutamic-acid": {
        "Code": "D4FG",
        "Formula": "C5H8FNO4",
        "Letter": "ṣ",
        "MolWeight": 165.043735956,
        "SMILES": "N[C@H](C[C@H](F)C(=O)O)C(=O)O",
        "cterm": "N[C@H](C[C@H](F)C*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Trifluoro-alanine": {
        "Code": "DFLA",
        "Formula": "C3H4F3NO2",
        "Letter": "ṧ",
        "MolWeight": 143.019413028,
        "SMILES": "N[C@H](C(F)(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-Fluoro-phenylglycine": {
        "Code": "DFP6",
        "Formula": "C8H8FNO2",
        "Letter": "ṩ",
        "MolWeight": 169.053906716,
        "SMILES": "N[C@H](c1ccccc1F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-Fluoro-phenylglycine": {
        "Code": "DFP7",
        "Formula": "C8H8FNO2",
        "Letter": "ṫ",
        "MolWeight": 169.053906716,
        "SMILES": "N[C@H](c1cccc(c1)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-Fluoro-phenylglycine": {
        "Code": "DFP8",
        "Formula": "C8H8FNO2",
        "Letter": "ṭ",
        "MolWeight": 169.053906716,
        "SMILES": "N[C@H](c1ccc(cc1)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-Fluoro-Phenylalanine": {
        "Code": "DFF2",
        "Formula": "C9H10FNO2",
        "Letter": "ṯ",
        "MolWeight": 183.06955678,
        "SMILES": "N[C@H](Cc1ccccc1F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-Fluoro-Phenylalanine": {
        "Code": "DFF3",
        "Formula": "C9H10FNO2",
        "Letter": "ṱ",
        "MolWeight": 183.06955678,
        "SMILES": "N[C@H](Cc1cccc(c1)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-6-fluoro-l-tryptophan": {
        "Code": "DFT6",
        "Formula": "C11H11FN2O2",
        "Letter": "ụ",
        "MolWeight": 222.080455812,
        "SMILES": "N[C@H](Cc1cNc2c1ccc(c2)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-5-Fluoro-tryptophan": {
        "Code": "DFTR",
        "Formula": "C11H11FN2O2",
        "Letter": "ủ",
        "MolWeight": 222.080455812,
        "SMILES": "N[C@H](Cc1c[nH]c2c1cc(F)cc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-(2-furyl)-alanine": {
        "Code": "DFUO",
        "Formula": "C7H9NO3",
        "Letter": "ứ",
        "MolWeight": 155.058243148,
        "SMILES": "N[C@H](Cc1ccco1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-Fluoro-valine": {
        "Code": "DFVL",
        "Formula": "C5H10FNO2",
        "Letter": "ừ",
        "MolWeight": 135.06955678,
        "SMILES": "N[C@H](C(F)(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-Amino-4-guanidinobutryric-acid": {
        "Code": "DGBT",
        "Formula": "C5H14N4O2",
        "Letter": "ử",
        "MolWeight": 162.111675688,
        "SMILES": "N[C@H](CCNC(N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CCNC(N)N*)C(=O)O",
    },
    "d-2-Amino-3-guanidinopropionic-acid": {
        "Code": "DGPA",
        "Formula": "C4H12N4O2",
        "Letter": "ữ",
        "MolWeight": 148.096025624,
        "SMILES": "N[C@H](CNC(N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CNC(N)N*)C(=O)O",
    },
    "d-Canavanine": {
        "Code": "DGGB",
        "Formula": "C5H12N4O3",
        "Letter": "ự",
        "MolWeight": 176.090940244,
        "SMILES": "N[C@H](CCON=C(N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CCON=C(N)N*)C(=O)O",
    },
    "d-(2s,4s)-2,5-diamino-4-hydroxy-5-oxopentanoic-acid": {
        "Code": "DGHG",
        "Formula": "C5H10N2O4",
        "Letter": "ṳ",
        "MolWeight": 162.0640568,
        "SMILES": "N[C@H](C[C@H](O)C(=O)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](C[C@H](O)C(=O)N*)C(=O)O",
    },
    "d-5-o-methyl-glutamic-acid": {
        "Code": "DGME",
        "Formula": "C6H11NO4",
        "Letter": "ṵ",
        "MolWeight": 161.068807832,
        "SMILES": "N[C@H](CCC(=O)OC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-homocysteine": {
        "Code": "DHCS",
        "Formula": "C4H9NO2S",
        "Letter": "ṷ",
        "MolWeight": 135.035399528,
        "SMILES": "N[C@H](CCS)C(=O)O",
        "cterm": False,
        "disulphide": "N[C@H](CCS*)C(=O)O",
        "ester": False,
        "nterm": False,
    },
    "d-glutamine-hydroxamate": {
        "Code": "DHGA",
        "Formula": "C5H10N2O4",
        "Letter": "ṹ",
        "MolWeight": 162.0640568,
        "SMILES": "N[C@H](CCC(=O)NO)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-(2s)-2,8-diaminooctanoic-acid": {
        "Code": "DHHK",
        "Formula": "C8H18N2O2",
        "Letter": "ṻ",
        "MolWeight": 174.136827816,
        "SMILES": "N[C@H](CCCCCCN)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CCCCCCN*)C(=O)O",
    },
    "d-4-Hydroxy-L-isoleucine": {
        "Code": "DHIL",
        "Formula": "C6H13NO3",
        "Letter": "ṽ",
        "MolWeight": 147.089543276,
        "SMILES": "N[C@H]([C@H]([C@@H](C)O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-(2s,3r)-2-amino-3-hydroxy-4-methylpentanoic-acid": {
        "Code": "DHL2",
        "Formula": "C6H13NO3",
        "Letter": "ṿ",
        "MolWeight": 147.089543276,
        "SMILES": "N[C@H]([C@H](O)C(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Homoleucine": {
        "Code": "DHL1",
        "Formula": "C7H15NO2",
        "Letter": "ẁ",
        "MolWeight": 145.11027872,
        "SMILES": "N[C@H](CCC(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-beta-hydroxyleucine": {
        "Code": "DHLU",
        "Formula": "C6H13NO3",
        "Letter": "ẃ",
        "MolWeight": 147.089543276,
        "SMILES": "N[C@H]([C@@H](O)C(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-amino-L-phenylalanine": {
        "Code": "DHOX",
        "Formula": "C9H12N2O2",
        "Letter": "ẅ",
        "MolWeight": 180.089877624,
        "SMILES": "N[C@H](Cc1ccc(cc1)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](Cc1ccc(cc1)N*)C(=O)O",
    },
    "d-Homophenylalanine": {
        "Code": "DHPE",
        "Formula": "C10H13NO2",
        "Letter": "ẇ",
        "MolWeight": 179.094628656,
        "SMILES": "N[C@H](CCc1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(8-hydroxyquinolin-3-yl)-l-alanine": {
        "Code": "DHQA",
        "Formula": "C12H12N2O3",
        "Letter": "ẉ",
        "MolWeight": 232.084792244,
        "SMILES": "N[C@H](Cc1cnc2c(c1)cccc2O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-homoarginine": {
        "Code": "DHRG",
        "Formula": "C7H18N4O2",
        "Letter": "ẋ",
        "MolWeight": 190.142975816,
        "SMILES": "N[C@H](CCCCNC(N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CCCCNC(N)N*)C(=O)O",
    },
    "d-5-Hydroxy-tryptophan": {
        "Code": "DHRP",
        "Formula": "C11H12N2O3",
        "Letter": "ẍ",
        "MolWeight": 220.084792244,
        "SMILES": "N[C@H](Cc1cNc2c1cc(O)cc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-homoserine": {
        "Code": "DHSE",
        "Formula": "C4H9NO3",
        "Letter": "ỳ",
        "MolWeight": 119.058243148,
        "SMILES": "N[C@H](CCO)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@H](CCO*)C(=O)O",
        "nterm": False,
    },
    "d-beta-hydroxy-tryptophane": {
        "Code": "DHTR",
        "Formula": "C11H12N2O3",
        "Letter": "ỵ",
        "MolWeight": 220.084792244,
        "SMILES": "N[C@H]([C@H](c1c[nH]c2c1cccc2)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-hydroxy-l-valine": {
        "Code": "DHVA",
        "Formula": "C5H11NO3",
        "Letter": "ỷ",
        "MolWeight": 133.073893212,
        "SMILES": "N[C@H](C(O)(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-methyl-l-alloisoleucine": {
        "Code": "DI2M",
        "Formula": "C7H15NO2",
        "Letter": "ỹ",
        "MolWeight": 145.11027872,
        "SMILES": "N[C@H](C(CC)(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-alpha-amino-2-indanacetic-acid": {
        "Code": "DIGL",
        "Formula": "C11H13NO2",
        "Letter": "ẏ",
        "MolWeight": 191.094628656,
        "SMILES": "N[C@H](C1Cc2c(C1)cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Allo-Isoleucine": {
        "Code": "DIIL",
        "Formula": "C6H13NO2",
        "Letter": "ẑ",
        "MolWeight": 131.094628656,
        "SMILES": "N[C@H]([C@@H](CC)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4,5-dihydroxy-isoleucine": {
        "Code": "DILX",
        "Formula": "C6H13NO4",
        "Letter": "ẓ",
        "MolWeight": 163.084457896,
        "SMILES": "N[C@H]([C@H]([C@H](CO)O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@H]([C@H]([C@H](CO*)O)C)C(=O)O",
        "nterm": False,
    },
    "d-3-iodo-tyrosine": {
        "Code": "DIYR",
        "Formula": "C9H10INO3",
        "Letter": "ẕ",
        "MolWeight": 306.97054117999994,
        "SMILES": "N[C@H](Cc1ccc(c(c1)I)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-kynurenine": {
        "Code": "DKYN",
        "Formula": "C10H12N2O3",
        "Letter": "ỻ",
        "MolWeight": 208.084792244,
        "SMILES": "N[C@H](CC(=O)c1ccccc1N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CC(=O)c1ccccc1N*)C(=O)O",
    },
    "d-6-hydroxy-l-norleucine": {
        "Code": "DLDO",
        "Formula": "C6H13NO3",
        "Letter": "ỽ",
        "MolWeight": 147.089543276,
        "SMILES": "N[C@H](CCCCO)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@H](CCCCO*)C(=O)O",
        "nterm": False,
    },
    "d-Penicillamine": {
        "Code": "DLE1",
        "Formula": "C5H11NO2S",
        "Letter": "ỿ",
        "MolWeight": 149.051049592,
        "SMILES": "N[C@H](C(S)(C)C)C(=O)O",
        "cterm": False,
        "disulphide": "N[C@H](C(S*)(C)C)C(=O)O",
        "ester": False,
        "nterm": False,
    },
    "d-(4r)-5-oxo-l-leucine": {
        "Code": "DLED",
        "Formula": "C6H11NO3",
        "Letter": "ÿ",
        "MolWeight": 145.073893212,
        "SMILES": "N[C@H](C[C@@H](C)C=O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-(4s)-5-fluoro-l-leucine": {
        "Code": "DLEF",
        "Formula": "C6H12FNO2",
        "Letter": "ý",
        "MolWeight": 149.085206844,
        "SMILES": "N[C@H](C[C@H](C)CF)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-(3r)-3-methyl-l-glutamic-acid": {
        "Code": "DLME",
        "Formula": "C6H11NO4",
        "Letter": "ā",
        "MolWeight": 161.068807832,
        "SMILES": "N[C@H]([C@H](C)CC(O)=O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-methyl-l-glutamine": {
        "Code": "DLMQ",
        "Formula": "C6H12N2O3",
        "Letter": "ă",
        "MolWeight": 160.084792244,
        "SMILES": "N[C@H]([C@@H](C)CC(N)=O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-vinylglycine": {
        "Code": "DLVG",
        "Formula": "C4H7NO2",
        "Letter": "ą",
        "MolWeight": 101.047678464,
        "SMILES": "N[C@H](C=C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-oxo-l-valine": {
        "Code": "DLVN",
        "Formula": "C5H9NO3",
        "Letter": "ć",
        "MolWeight": 131.058243148,
        "SMILES": "N[C@H]([C@H](C)C=O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3,3-dimethyl-methionine-sulfoxide": {
        "Code": "DM2S",
        "Formula": "C7H15NO3S",
        "Letter": "ĉ",
        "MolWeight": 193.07726434,
        "SMILES": "N[C@H](C(C)(C)C[S@@](C)=O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-hydroxy-l-methionine": {
        "Code": "DME0",
        "Formula": "C5H11NO3S",
        "Letter": "ċ",
        "MolWeight": 165.045964212,
        "SMILES": "N[C@H](CCSCO)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@H](CCSCO*)C(=O)O",
        "nterm": False,
    },
    "d-(3s)-3-methyl-l-glutamic-acid": {
        "Code": "DMEG",
        "Formula": "C6H11NO4",
        "Letter": "č",
        "MolWeight": 161.068807832,
        "SMILES": "N[C@H]([C@@H](C)CC(=O)O)C(=O)O",
        "cterm": "N[C@H]([C@@H](C)CC*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-n-methyl-asparagine": {
        "Code": "DMEN",
        "Formula": "C5H10N2O3",
        "Letter": "ď",
        "MolWeight": 146.06914218,
        "SMILES": "N[C@H](CC(=O)NC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-n5-methyl-glutamine": {
        "Code": "DMEQ",
        "Formula": "C6H12N2O3",
        "Letter": "đ",
        "MolWeight": 160.084792244,
        "SMILES": "N[C@H](CCC(=O)NC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-s-oxymethionine": {
        "Code": "DMHO",
        "Formula": "C5H11NO3S",
        "Letter": "ē",
        "MolWeight": 165.045964212,
        "SMILES": "N[C@H](CC[S@](=O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-5-Methoxy-tryptophan": {
        "Code": "D5XW",
        "Formula": "C12H14N2O3",
        "Letter": "ĕ",
        "MolWeight": 234.100442308,
        "SMILES": "N[C@H](Cc1cNc2ccc(OC)cc12)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3,4-Dimethyl-phenylalanine": {
        "Code": "DM34",
        "Formula": "C11H15NO2",
        "Letter": "ė",
        "MolWeight": 193.11027872,
        "SMILES": "N[C@H](Cc1ccc(c(c1)C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-Methyl-phenylalanine": {
        "Code": "D2MF",
        "Formula": "C10H13NO2",
        "Letter": "ę",
        "MolWeight": 179.094628656,
        "SMILES": "N[C@H](Cc1ccccc1C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-5-Methyl-tryptophan": {
        "Code": "D5MW",
        "Formula": "C12H14N2O2",
        "Letter": "ě",
        "MolWeight": 218.105527688,
        "SMILES": "N[C@H](Cc1cNc2ccc(C)cc12)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-6-Methyl-tryptophan": {
        "Code": "D6MW",
        "Formula": "C12H14N2O2",
        "Letter": "ĝ",
        "MolWeight": 218.105527688,
        "SMILES": "N[C@H](Cc1cNc2c1ccc(c2)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-m-Tyrosine": {
        "Code": "DMTY",
        "Formula": "C9H11NO3",
        "Letter": "ğ",
        "MolWeight": 181.073893212,
        "SMILES": "N[C@H](Cc1cccc(c1)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-Naphthyl-alanine": {
        "Code": "DNAL",
        "Formula": "C13H13NO2",
        "Letter": "ġ",
        "MolWeight": 215.094628656,
        "SMILES": "N[C@H](Cc1ccc2c(c1)cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-5-hydroxy-1-naphthalene": {
        "Code": "D51N",
        "Formula": "C13H13NO3",
        "Letter": "ģ",
        "MolWeight": 231.089543276,
        "SMILES": "N[C@H](Cc1cccc2c1cc(O)cc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-6-hydroxy-2-naphthalene": {
        "Code": "D62N",
        "Formula": "C13H13NO3",
        "Letter": "ĥ",
        "MolWeight": 231.089543276,
        "SMILES": "N[C@H](Cc1ccc2c(c1)cc(cc2)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-meta-nitro-tyrosine": {
        "Code": "DNIY",
        "Formula": "C9H10N2O5",
        "Letter": "ħ",
        "MolWeight": 226.05897142,
        "SMILES": "N[C@H](Cc1ccc(c(c1)N(=O)=O)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Norleucine": {
        "Code": "DNLE",
        "Formula": "C6H13NO2",
        "Letter": "ĩ",
        "MolWeight": 131.094628656,
        "SMILES": "N[C@H](CCCC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Norvaline": {
        "Code": "DNVA",
        "Formula": "C5H11NO2",
        "Letter": "ī",
        "MolWeight": 117.078978592,
        "SMILES": "N[C@H](CCC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-o-acetylserine": {
        "Code": "DOAS",
        "Formula": "C5H9NO4",
        "Letter": "ĭ",
        "MolWeight": 147.053157768,
        "SMILES": "N[C@H](COC(=O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-(2s)-2-amino-4,4-difluorobutanoic-acid": {
        "Code": "DOBF",
        "Formula": "C4H7F2NO2",
        "Letter": "į",
        "MolWeight": 139.044484904,
        "SMILES": "N[C@H](CC(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-s-(2-hydroxyethyl)-l-cysteine": {
        "Code": "DOCY",
        "Formula": "C5H11NO3S",
        "Letter": "þ",
        "MolWeight": 165.045964212,
        "SMILES": "N[C@H](CSCCO)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@H](CSCCO*)C(=O)O",
        "nterm": False,
    },
    "d-o-methyl-l-threonine": {
        "Code": "DOLT",
        "Formula": "C5H11NO3",
        "Letter": "ĳ",
        "MolWeight": 133.073893212,
        "SMILES": "N[C@H]([C@H](OC)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Methionine-sulfone": {
        "Code": "DOMT",
        "Formula": "C5H11NO4S",
        "Letter": "ĵ",
        "MolWeight": 181.040878832,
        "SMILES": "N[C@H](CCS(=O)(=O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-(betar)-beta-hydroxy-l-tyrosine": {
        "Code": "DOMX",
        "Formula": "C9H11NO4",
        "Letter": "ķ",
        "MolWeight": 197.068807832,
        "SMILES": "N[C@H]([C@@H](c1ccc(cc1)O)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-(betar)-3-chloro-beta-hydroxy-l-tyrosine": {
        "Code": "DOMY",
        "Formula": "C9H10ClNO4",
        "Letter": "ĺ",
        "MolWeight": 231.02983548,
        "SMILES": "N[C@H]([C@@H](c1ccc(c(c1)Cl)O)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-5-oxo-l-norleucine": {
        "Code": "DONL",
        "Formula": "C6H11NO3",
        "Letter": "ļ",
        "MolWeight": 145.073893212,
        "SMILES": "N[C@H](CCC(=O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Ornithine": {
        "Code": "DORN",
        "Formula": "C5H12N2O2",
        "Letter": "ľ",
        "MolWeight": 132.089877624,
        "SMILES": "N[C@H](CCCN)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CCCN*)C(=O)O",
    },
    "d-o-Tyrosine": {
        "Code": "D2TR",
        "Formula": "C9H11NO3",
        "Letter": "ŀ",
        "MolWeight": 181.073893212,
        "SMILES": "N[C@H](Cc1ccccc1O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-benzoyl-phenylalanine": {
        "Code": "DPBF",
        "Formula": "C16H15NO3",
        "Letter": "ł",
        "MolWeight": 269.10519334,
        "SMILES": "N[C@H](Cc1ccc(cc1)C(=O)c1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-pentafluoro-phenylalanine": {
        "Code": "DPF5",
        "Formula": "C9H6F5NO2",
        "Letter": "ń",
        "MolWeight": 255.031869532,
        "SMILES": "N[C@H](Cc1c(F)c(F)c(c(c1F)F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-Fluoro-Phenylalanine": {
        "Code": "DPFF",
        "Formula": "C9H10FNO2",
        "Letter": "ņ",
        "MolWeight": 183.06955678,
        "SMILES": "N[C@H](Cc1ccc(cc1)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-Iodo-Phenylalanine": {
        "Code": "DPHI",
        "Formula": "C9H10INO2",
        "Letter": "ň",
        "MolWeight": 290.97562655999997,
        "SMILES": "N[C@H](Cc1ccc(cc1)I)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-Nitro-phenylalanine": {
        "Code": "DPPN",
        "Formula": "C9H10N2O4",
        "Letter": "ŋ",
        "MolWeight": 210.0640568,
        "SMILES": "N[C@H](Cc1ccc(cc1)N(=O)=O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-phosphotyrosine": {
        "Code": "DPTR",
        "Formula": "C9H12NO6P",
        "Letter": "ō",
        "MolWeight": 261.04022373400005,
        "SMILES": "N[C@H](Cc1ccc(cc1)OP(=O)(O)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(2-Pyridyl)-alanine": {
        "Code": "DY23",
        "Formula": "C8H10N2O2",
        "Letter": "ŏ",
        "MolWeight": 166.07422756,
        "SMILES": "N[C@H](Cc1ccccn1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(3-Pyridyl)-alanine": {
        "Code": "DY33",
        "Formula": "C8H10N2O2",
        "Letter": "ő",
        "MolWeight": 166.07422756,
        "SMILES": "N[C@H](Cc1cccnc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(4-Pyridyl)-alanine": {
        "Code": "DY34",
        "Formula": "C8H10N2O2",
        "Letter": "œ",
        "MolWeight": 166.07422756,
        "SMILES": "N[C@H](Cc1ccncc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(1-Pyrazolyl)-alanine": {
        "Code": "DPZ4",
        "Formula": "C6H9N3O2",
        "Letter": "ŕ",
        "MolWeight": 155.069476528,
        "SMILES": "N[C@H](Cn1cccn1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(2-Quinolyl)-alanine": {
        "Code": "DQ32",
        "Formula": "C12H12N2O2",
        "Letter": "ŗ",
        "MolWeight": 216.089877624,
        "SMILES": "N[C@H](Cc1ccc2c(n1)cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(3-quinolyl)-alanine": {
        "Code": "DQ33",
        "Formula": "C12H12N2O2",
        "Letter": "ř",
        "MolWeight": 216.089877624,
        "SMILES": "N[C@H](Cc1cnc2c(c1)cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(4-quinolyl)-alanine": {
        "Code": "DQ34",
        "Formula": "C12H12N2O2",
        "Letter": "ś",
        "MolWeight": 216.089877624,
        "SMILES": "N[C@H](Cc1ccnc2c1cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(5-Quinolyl)-alanine": {
        "Code": "DQ35",
        "Formula": "C12H12N2O2",
        "Letter": "ŝ",
        "MolWeight": 216.089877624,
        "SMILES": "N[C@H](Cc1ccc2c(c1)nccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(6-Quinolyl)-alanine": {
        "Code": "DQ36",
        "Formula": "C12H12N2O2",
        "Letter": "ş",
        "MolWeight": 216.089877624,
        "SMILES": "N[C@H](Cc1ccc2c(c1)cncc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(2-quinoxalyl)-alanine": {
        "Code": "DQX3",
        "Formula": "C11H11N3O2",
        "Letter": "š",
        "MolWeight": 217.085126592,
        "SMILES": "N[C@H](Cc1cnc2c(n1)cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-phosphoserine": {
        "Code": "DSEP",
        "Formula": "C3H8NO6P",
        "Letter": "ţ",
        "MolWeight": 185.008923606,
        "SMILES": "N[C@H](COP(=O)(O)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-thialysine": {
        "Code": "DSLZ",
        "Formula": "C5H12N2O2S",
        "Letter": "ť",
        "MolWeight": 164.061948624,
        "SMILES": "N[C@H](CSCCN)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CSCCN*)C(=O)O",
    },
    "d-Methionine-sulfoxide": {
        "Code": "DSME",
        "Formula": "C5H11NO3S",
        "Letter": "ŧ",
        "MolWeight": 165.045964212,
        "SMILES": "N[C@H](CC[S@](=O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Styrylalanine": {
        "Code": "DSYA",
        "Formula": "C11H13NO2",
        "Letter": "ũ",
        "MolWeight": 191.094628656,
        "SMILES": "N[C@H](CC=Cc1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2s,4r-4-methylglutamate": {
        "Code": "DSYM",
        "Formula": "C6H11NO4",
        "Letter": "ū",
        "MolWeight": 161.068807832,
        "SMILES": "N[C@H](C[C@H](C(=O)O)C)C(=O)O",
        "cterm": "N[C@H](C[C@H](C*(=O))C)C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-tert-butyl-phenylalanine": {
        "Code": "D4TF",
        "Formula": "C13H19NO2",
        "Letter": "ŭ",
        "MolWeight": 221.141578848,
        "SMILES": "N[C@H](Cc1ccc(cc1)C(C)(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(2-Tetrazolyl)-alanine": {
        "Code": "DTEZ",
        "Formula": "C4H7N5O2",
        "Letter": "ů",
        "MolWeight": 157.059974464,
        "SMILES": "N[C@H](Cn1nncn1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-(Trifluoromethyl)-phenylglycine": {
        "Code": "D2TG",
        "Formula": "C9H8F3NO2",
        "Letter": "ű",
        "MolWeight": 219.050713156,
        "SMILES": "N[C@H](c1ccccc1C(F)(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(Trifluoromethyl)-phenylglycine": {
        "Code": "D3TG",
        "Formula": "C9H8F3NO2",
        "Letter": "ų",
        "MolWeight": 219.050713156,
        "SMILES": "N[C@H](c1cccc(c1)C(F)(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-(Trifluoromethyl)-phenylglycine": {
        "Code": "D4TG",
        "Formula": "C9H8F3NO2",
        "Letter": "ŵ",
        "MolWeight": 219.050713156,
        "SMILES": "N[C@H](c1ccc(cc1)C(F)(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-5,5,5-Trifluoro-leucine": {
        "Code": "DTFL",
        "Formula": "C6H10F3NO2",
        "Letter": "ŷ",
        "MolWeight": 185.06636322,
        "SMILES": "N[C@H](C[C@@H](C(F)(F)F)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-(Trifluoromethyl)-phenylalanine": {
        "Code": "D2TF",
        "Formula": "C10H10F3NO2",
        "Letter": "ź",
        "MolWeight": 233.06636322,
        "SMILES": "N[C@H](Cc1ccccc1C(F)(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(Trifluoromethyl)-phenylalanine": {
        "Code": "D3TF",
        "Formula": "C10H10F3NO2",
        "Letter": "ż",
        "MolWeight": 233.06636322,
        "SMILES": "N[C@H](Cc1cccc(c1)C(F)(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-(Trifluoromethyl)-phenylalanine": {
        "Code": "D4TM",
        "Formula": "C10H10F3NO2",
        "Letter": "ž",
        "MolWeight": 233.06636322,
        "SMILES": "N[C@H](Cc1ccc(cc1)C(F)(F)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-4-hydroxy-l-threonine": {
        "Code": "DTH6",
        "Formula": "C4H9NO4",
        "Letter": "à",
        "MolWeight": 135.053157768,
        "SMILES": "N[C@H]([C@H](O)CO)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@H]([C@H](O)CO*)C(=O)O",
        "nterm": False,
    },
    "d-3-(3-thienyl)-alanine": {
        "Code": "D3TA",
        "Formula": "C7H9NO2S",
        "Letter": "á",
        "MolWeight": 171.035399528,
        "SMILES": "N[C@H](Cc1cscc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-thienylglycine": {
        "Code": "D2TH",
        "Formula": "C6H7NO2S",
        "Letter": "â",
        "MolWeight": 157.019749464,
        "SMILES": "N[C@H](c1cccs1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-thienylglycine": {
        "Code": "D3TH",
        "Formula": "C6H7NO2S",
        "Letter": "ã",
        "MolWeight": 157.019749464,
        "SMILES": "N[C@H](c1cscc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Thio-citrulline": {
        "Code": "DTVI",
        "Formula": "C6H13N3O2S",
        "Letter": "ä",
        "MolWeight": 191.072847656,
        "SMILES": "N[C@H](CCCNC(=S)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CCCNC(=S)N*)C(=O)O",
    },
    "d-3-(2-thienyl)-alanine": {
        "Code": "DTIH",
        "Formula": "C7H9NO2S",
        "Letter": "å",
        "MolWeight": 171.035399528,
        "SMILES": "N[C@H](Cc1cccs1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-phosphothreonine": {
        "Code": "DTPO",
        "Formula": "C4H10NO6P",
        "Letter": "æ",
        "MolWeight": 199.02457367,
        "SMILES": "N[C@H]([C@H](OP(=O)(O)O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-hydroxy-tryptophan": {
        "Code": "DTRO",
        "Formula": "C11H12N2O3",
        "Letter": "ç",
        "MolWeight": 220.084792244,
        "SMILES": "N[C@H](Cc1c(O)[nH]c2c1cccc2)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-6-hydroxy-tryptophan": {
        "Code": "DTRX",
        "Formula": "C11H12N2O3",
        "Letter": "è",
        "MolWeight": 220.084792244,
        "SMILES": "N[C@H](Cc1c[nH]c2c1ccc(c2)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-(1,2,4-Triazol-1-yl)-alanine": {
        "Code": "DTZR",
        "Formula": "C5H8N4O2",
        "Letter": "é",
        "MolWeight": 156.064725496,
        "SMILES": "N[C@H](Cn1cncn1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-6-amino-7-hydroxy-l-tryptophan": {
        "Code": "DTTQ",
        "Formula": "C11H13N3O3",
        "Letter": "ê",
        "MolWeight": 235.095691276,
        "SMILES": "N[C@H](Cc1c[nH]c2c1ccc(c2O)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](Cc1c[nH]c2c1ccc(c2O)N*)C(=O)O",
    },
    "d-3-Amino-L-tyrosine": {
        "Code": "DTY2",
        "Formula": "C9H12N2O3",
        "Letter": "ë",
        "MolWeight": 196.084792244,
        "SMILES": "N[C@H](Cc1ccc(c(c1)N)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3,5-diiodotyrosine": {
        "Code": "DTYI",
        "Formula": "C9H9I2NO3",
        "Letter": "ì",
        "MolWeight": 432.8671891479999,
        "SMILES": "N[C@H](Cc1cc(I)c(c(c1)I)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3-amino-6-hydroxy-tyrosine": {
        "Code": "DTYQ",
        "Formula": "C9H12N2O4",
        "Letter": "í",
        "MolWeight": 212.079706864,
        "SMILES": "N[C@H](Cc1cc(N)c(cc1O)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-(4-thiazolyl)-alanine": {
        "Code": "D4TH",
        "Formula": "C6H8N2O2S",
        "Letter": "î",
        "MolWeight": 172.030648496,
        "SMILES": "N[C@H](Cc1cscn1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-2-Aminoadipic-acid": {
        "Code": "DUN1",
        "Formula": "C6H11NO4",
        "Letter": "ï",
        "MolWeight": 161.068807832,
        "SMILES": "N[C@H](CCCC(=O)O)C(=O)O",
        "cterm": "N[C@H](CCCC*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-Hydroxynorvaline": {
        "Code": "DVAH",
        "Formula": "C5H11NO3",
        "Letter": "ð",
        "MolWeight": 133.073893212,
        "SMILES": "N[C@H]([C@H](O)CC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-3,5-Difluoro-phenylalanine": {
        "Code": "DWFP",
        "Formula": "C9H9F2NO2",
        "Letter": "ñ",
        "MolWeight": 201.060134968,
        "SMILES": "N[C@H](Cc1cc(F)cc(c1)F)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "d-cysteine-s-acetamide": {
        "Code": "DYCM",
        "Formula": "C5H10N2O3S",
        "Letter": "ò",
        "MolWeight": 178.04121318,
        "SMILES": "N[C@H](CSCC(=O)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CSCC(=O)N*)C(=O)O",
    },
    "d-3-fluorotyrosine": {
        "Code": "DYOF",
        "Formula": "C9H10FNO3",
        "Letter": "ó",
        "MolWeight": 199.0644714,
        "SMILES": "N[C@H](Cc1ccc(c(c1)F)O)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "Glycine": {
        "Code": "Gly",
        "Formula": "C2H5NO2",
        "Letter": "G",
        "MolWeight": "75.07",
        "SMILES": "NCC(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "L-Alanine": {
        "Code": "Ala",
        "Formula": "C3H7NO2",
        "Letter": "A",
        "MolWeight": "89.09",
        "SMILES": "N[C@@H](C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "L-Arginine": {
        "Code": "Arg",
        "Formula": "C6H14N4O2",
        "Letter": "R",
        "MolWeight": "174.20",
        "SMILES": "N[C@@H](CCCNC(=N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CCCNC(=N*)N)C(=O)O",
    },
    "L-Asparagine": {
        "Code": "Asn",
        "Formula": "C4H8N2O3",
        "Letter": "N",
        "MolWeight": "132.12",
        "SMILES": "N[C@@H](CC(=O)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CC(=O)N*)C(=O)O",
    },
    "L-Aspartic_Acid": {
        "Code": "Asp",
        "Formula": "C4H7NO4",
        "Letter": "D",
        "MolWeight": "133.10",
        "SMILES": "N[C@@H](CC(=O)O)C(=O)O",
        "cterm": "N[C@@H](CC*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "L-Cysteine": {
        "Code": "Cys",
        "Formula": "C3H7NO2S",
        "Letter": "C",
        "MolWeight": "121.16",
        "SMILES": "N[C@@H](CS)C(=O)O",
        "cterm": False,
        "disulphide": "N[C@@H](CS*)C(=O)O",
        "ester": False,
        "nterm": False,
    },
    "L-Glutamic_Acid": {
        "Code": "Glu",
        "Formula": "C5H9NO4",
        "Letter": "E",
        "MolWeight": "147.13",
        "SMILES": "N[C@@H](CCC(=O)O)C(=O)O",
        "cterm": "N[C@@H](CCC*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "L-Glutamine": {
        "Code": "Gln",
        "Formula": "C5H10N2O3",
        "Letter": "Q",
        "MolWeight": "146.15",
        "SMILES": "N[C@@H](CCC(=O)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CCC(=O)N*)C(=O)O",
    },
    "L-Histidine": {
        "Code": "His",
        "Formula": "C6H9N3O2",
        "Letter": "H",
        "MolWeight": "155.16",
        "SMILES": "N[C@@H](CC1=CNC=N1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "L-Isoleucine": {
        "Code": "Ile",
        "Formula": "C6H13NO2",
        "Letter": "I",
        "MolWeight": "131.18",
        "SMILES": "N[C@@H]([C@H](CC)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "L-Leucine": {
        "Code": "Leu",
        "Formula": "C6H13NO2",
        "Letter": "L",
        "MolWeight": "131.18",
        "SMILES": "N[C@@H](CC(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "L-Lysine": {
        "Code": "Lys",
        "Formula": "C6H12N2O2",
        "Letter": "K",
        "MolWeight": "146.19",
        "SMILES": "N[C@@H](CCCCN)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@@H](CCCCN*)C(=O)O",
    },
    "L-Methionine": {
        "Code": "Met",
        "Formula": "C5H11NO2S",
        "Letter": "M",
        "MolWeight": "149.21",
        "SMILES": "N[C@@H](CCSC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "L-Phenylalanine": {
        "Code": "Phe",
        "Formula": "C9H11NO2",
        "Letter": "F",
        "MolWeight": "165.19",
        "SMILES": "N[C@@H](Cc1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "L-Proline": {
        "Code": "Pro",
        "Formula": "C5H9NO2",
        "Letter": "P",
        "MolWeight": "115.13",
        "SMILES": "N1[C@@H](CCC1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "L-Serine": {
        "Code": "Ser",
        "Formula": "C3H7NO2",
        "Letter": "S",
        "MolWeight": "105.09",
        "SMILES": "N[C@@H](CO)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@@H](CO*)C(=O)O",
        "nterm": False,
    },
    "L-Threonine": {
        "Code": "Thr",
        "Formula": "C4H9NO3",
        "Letter": "T",
        "MolWeight": "119.12",
        "SMILES": "N[C@@H]([C@H](O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@@H]([C@H](O*)C)C(=O)O",
        "nterm": False,
    },
    "L-Tryptophan": {
        "Code": "Trp",
        "Formula": "C11H12N2O2",
        "Letter": "W",
        "MolWeight": "204.23",
        "SMILES": "N[C@@H](CC(=CN2)C1=C2C=CC=C1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "L-Tyrosine": {
        "Code": "Tyr",
        "Formula": "C9H11NO3",
        "Letter": "Y",
        "MolWeight": "181.19",
        "SMILES": "N[C@@H](Cc1ccc(O)cc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@@H](Cc1ccc(O*)cc1)C(=O)O",
        "nterm": False,
    },
    "L-Valine": {
        "Code": "Val",
        "Formula": "C5H11NO2",
        "Letter": "V",
        "MolWeight": "117.15",
        "SMILES": "N[C@@H](C(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "D-Alanine": {
        "Code": "ala",
        "Formula": "C3H7NO2",
        "Letter": "a",
        "MolWeight": "89.09",
        "SMILES": "N[C@H](C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "D-Arginine": {
        "Code": "arg",
        "Formula": "C6H14N4O2",
        "Letter": "r",
        "MolWeight": "174.20",
        "SMILES": "N[C@H](CCCNC(=N)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CCCNC(=N*)N)C(=O)O",
    },
    "D-Asparagine": {
        "Code": "asn",
        "Formula": "C4H8N2O3",
        "Letter": "n",
        "MolWeight": "132.12",
        "SMILES": "N[C@H](CC(=O)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CC(=O)N*)C(=O)O",
    },
    "D-Aspartic_Acid": {
        "Code": "asp",
        "Formula": "C4H7NO4",
        "Letter": "d",
        "MolWeight": "133.10",
        "SMILES": "N[C@H](CC(=O)O)C(=O)O",
        "cterm": "N[C@H](CC*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "D-Cysteine": {
        "Code": "cys",
        "Formula": "C3H7NO2S",
        "Letter": "c",
        "MolWeight": "121.16",
        "SMILES": "N[C@H](CS)C(=O)O",
        "cterm": False,
        "disulphide": "N[C@H](CS*)C(=O)O",
        "ester": False,
        "nterm": False,
    },
    "D-Glutamic_Acid": {
        "Code": "glu",
        "Formula": "C5H9NO4",
        "Letter": "e",
        "MolWeight": "147.13",
        "SMILES": "N[C@H](CCC(=O)O)C(=O)O",
        "cterm": "N[C@H](CCC*(=O))C(=O)O",
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "D-Glutamine": {
        "Code": "gln",
        "Formula": "C5H10N2O3",
        "Letter": "q",
        "MolWeight": "146.15",
        "SMILES": "N[C@H](CCC(=O)N)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CCC(=O)N*)C(=O)O",
    },
    "D-Histidine": {
        "Code": "his",
        "Formula": "C6H9N3O2",
        "Letter": "h",
        "MolWeight": "155.16",
        "SMILES": "N[C@H](CC1=CNC=N1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "D-Isoleucine": {
        "Code": "ile",
        "Formula": "C6H13NO2",
        "Letter": "i",
        "MolWeight": "131.18",
        "SMILES": "N[C@H]([C@@H](CC)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "D-Leucine": {
        "Code": "leu",
        "Formula": "C6H13NO2",
        "Letter": "l",
        "MolWeight": "131.18",
        "SMILES": "N[C@H](CC(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "D-Lysine": {
        "Code": "lys",
        "Formula": "C6H12N2O2",
        "Letter": "k",
        "MolWeight": "146.19",
        "SMILES": "N[C@H](CCCCN)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": "N[C@H](CCCCN*)C(=O)O",
    },
    "D-Methionine": {
        "Code": "met",
        "Formula": "C5H11NO2S",
        "Letter": "m",
        "MolWeight": "149.21",
        "SMILES": "N[C@H](CCSC)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "D-Phenylalanine": {
        "Code": "phe",
        "Formula": "C9H11NO2",
        "Letter": "f",
        "MolWeight": "165.19",
        "SMILES": "N[C@H](Cc1ccccc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "D-Proline": {
        "Code": "pro",
        "Formula": "C5H9NO2",
        "Letter": "p",
        "MolWeight": "115.13",
        "SMILES": "N1[C@H](CCC1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "D-Serine": {
        "Code": "ser",
        "Formula": "C3H7NO2",
        "Letter": "s",
        "MolWeight": "105.09",
        "SMILES": "N[C@H](CO)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@H](CO*)C(=O)O",
        "nterm": False,
    },
    "D-Tryptophan": {
        "Code": "trp",
        "Formula": "C11H12N2O2",
        "Letter": "w",
        "MolWeight": "204.23",
        "SMILES": "N[C@H](CC(=CN2)C1=C2C=CC=C1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "D-Tyrosine": {
        "Code": "tyr",
        "Formula": "C9H11NO3",
        "Letter": "y",
        "MolWeight": "181.19",
        "SMILES": "N[C@H](Cc1ccc(O)cc1)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@H](Cc1ccc(O*)cc1)C(=O)O",
        "nterm": False,
    },
    "D-Valine": {
        "Code": "val",
        "Formula": "C5H11NO2",
        "Letter": "v",
        "MolWeight": "117.15",
        "SMILES": "N[C@H](C(C)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": False,
        "nterm": False,
    },
    "D-Threonine": {
        "Code": "thr",
        "Formula": "C4H9NO3",
        "Letter": "t",
        "MolWeight": "119.12",
        "SMILES": "N[C@H]([C@@H](O)C)C(=O)O",
        "cterm": False,
        "disulphide": False,
        "ester": "N[C@H]([C@@H](O*)C)C(=O)O",
        "nterm": False,
    },
}
